/*
 * SPDX-FileCopyrightText: Copyright (c) 2001-2010 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

/* AUTO GENERATED FILE -- DO NOT EDIT */

#ifndef __CLC597TEX_H__
#define __CLC597TEX_H__

/*
** Texture Header State Blocklinear
 */

#define NVC597_TEXHEAD_BL_COMPONENTS                               MW(6:0)
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_INVALID                 0x00000000
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_R32_G32_B32_A32         0x00000001
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_R32_G32_B32             0x00000002
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_R16_G16_B16_A16         0x00000003
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_R32_G32                 0x00000004
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_R32_B24G8               0x00000005
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_X8B8G8R8                0x00000007
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_A8B8G8R8                0x00000008
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_A2B10G10R10             0x00000009
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_R16_G16                 0x0000000c
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_G8R24                   0x0000000d
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_G24R8                   0x0000000e
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_R32                     0x0000000f
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_A4B4G4R4                0x00000012
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_A5B5G5R1                0x00000013
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_A1B5G5R5                0x00000014
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_B5G6R5                  0x00000015
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_B6G5R5                  0x00000016
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_G8R8                    0x00000018
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_R16                     0x0000001b
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_Y8_VIDEO                0x0000001c
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_R8                      0x0000001d
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_G4R4                    0x0000001e
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_R1                      0x0000001f
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_E5B9G9R9_SHAREDEXP      0x00000020
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_BF10GF11RF11            0x00000021
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_G8B8G8R8                0x00000022
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_B8G8R8G8                0x00000023
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_DXT1                    0x00000024
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_DXT23                   0x00000025
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_DXT45                   0x00000026
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_DXN1                    0x00000027
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_DXN2                    0x00000028
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_BC6H_SF16               0x00000010
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_BC6H_UF16               0x00000011
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_BC7U                    0x00000017
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ETC2_RGB                0x00000006
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ETC2_RGB_PTA            0x0000000a
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ETC2_RGBA               0x0000000b
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_EAC                     0x00000019
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_EACX2                   0x0000001a
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_Z24S8                   0x00000029
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_X8Z24                   0x0000002a
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_S8Z24                   0x0000002b
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_X4V4Z24__COV4R4V        0x0000002c
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_X4V4Z24__COV8R8V        0x0000002d
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_V8Z24__COV4R12V         0x0000002e
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ZF32                    0x0000002f
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ZF32_X24S8              0x00000030
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_X8Z24_X20V4S8__COV4R4V  0x00000031
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_X8Z24_X20V4S8__COV8R8V  0x00000032
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ZF32_X20V4X8__COV4R4V   0x00000033
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ZF32_X20V4X8__COV8R8V   0x00000034
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ZF32_X20V4S8__COV4R4V   0x00000035
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ZF32_X20V4S8__COV8R8V   0x00000036
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_X8Z24_X16V8S8__COV4R12V 0x00000037
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ZF32_X16V8X8__COV4R12V  0x00000038
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ZF32_X16V8S8__COV4R12V  0x00000039
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_Z16                     0x0000003a
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_V8Z24__COV8R24V         0x0000003b
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_X8Z24_X16V8S8__COV8R24V 0x0000003c
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ZF32_X16V8X8__COV8R24V  0x0000003d
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ZF32_X16V8S8__COV8R24V  0x0000003e
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_4X4             0x00000040
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_5X4             0x00000050
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_5X5             0x00000041
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_6X5             0x00000051
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_6X6             0x00000042
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_8X5             0x00000055
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_8X6             0x00000052
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_8X8             0x00000044
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X5            0x00000056
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X6            0x00000057
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X8            0x00000053
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X10           0x00000045
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_12X10           0x00000054
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_12X12           0x00000046
#define NVC597_TEXHEAD_BL_COMPONENTS_SIZES_CS_BITFIELD_SIZE        0x0000007f
#define NVC597_TEXHEAD_BL_R_DATA_TYPE                              MW(9:7)
#define NVC597_TEXHEAD_BL_R_DATA_TYPE_NUM_SNORM                    0x00000001
#define NVC597_TEXHEAD_BL_R_DATA_TYPE_NUM_UNORM                    0x00000002
#define NVC597_TEXHEAD_BL_R_DATA_TYPE_NUM_SINT                     0x00000003
#define NVC597_TEXHEAD_BL_R_DATA_TYPE_NUM_UINT                     0x00000004
#define NVC597_TEXHEAD_BL_R_DATA_TYPE_NUM_SNORM_FORCE_FP16         0x00000005
#define NVC597_TEXHEAD_BL_R_DATA_TYPE_NUM_UNORM_FORCE_FP16         0x00000006
#define NVC597_TEXHEAD_BL_R_DATA_TYPE_NUM_FLOAT                    0x00000007
#define NVC597_TEXHEAD_BL_G_DATA_TYPE                              MW(12:10)
#define NVC597_TEXHEAD_BL_G_DATA_TYPE_NUM_SNORM                    0x00000001
#define NVC597_TEXHEAD_BL_G_DATA_TYPE_NUM_UNORM                    0x00000002
#define NVC597_TEXHEAD_BL_G_DATA_TYPE_NUM_SINT                     0x00000003
#define NVC597_TEXHEAD_BL_G_DATA_TYPE_NUM_UINT                     0x00000004
#define NVC597_TEXHEAD_BL_G_DATA_TYPE_NUM_SNORM_FORCE_FP16         0x00000005
#define NVC597_TEXHEAD_BL_G_DATA_TYPE_NUM_UNORM_FORCE_FP16         0x00000006
#define NVC597_TEXHEAD_BL_G_DATA_TYPE_NUM_FLOAT                    0x00000007
#define NVC597_TEXHEAD_BL_B_DATA_TYPE                              MW(15:13)
#define NVC597_TEXHEAD_BL_B_DATA_TYPE_NUM_SNORM                    0x00000001
#define NVC597_TEXHEAD_BL_B_DATA_TYPE_NUM_UNORM                    0x00000002
#define NVC597_TEXHEAD_BL_B_DATA_TYPE_NUM_SINT                     0x00000003
#define NVC597_TEXHEAD_BL_B_DATA_TYPE_NUM_UINT                     0x00000004
#define NVC597_TEXHEAD_BL_B_DATA_TYPE_NUM_SNORM_FORCE_FP16         0x00000005
#define NVC597_TEXHEAD_BL_B_DATA_TYPE_NUM_UNORM_FORCE_FP16         0x00000006
#define NVC597_TEXHEAD_BL_B_DATA_TYPE_NUM_FLOAT                    0x00000007
#define NVC597_TEXHEAD_BL_A_DATA_TYPE                              MW(18:16)
#define NVC597_TEXHEAD_BL_A_DATA_TYPE_NUM_SNORM                    0x00000001
#define NVC597_TEXHEAD_BL_A_DATA_TYPE_NUM_UNORM                    0x00000002
#define NVC597_TEXHEAD_BL_A_DATA_TYPE_NUM_SINT                     0x00000003
#define NVC597_TEXHEAD_BL_A_DATA_TYPE_NUM_UINT                     0x00000004
#define NVC597_TEXHEAD_BL_A_DATA_TYPE_NUM_SNORM_FORCE_FP16         0x00000005
#define NVC597_TEXHEAD_BL_A_DATA_TYPE_NUM_UNORM_FORCE_FP16         0x00000006
#define NVC597_TEXHEAD_BL_A_DATA_TYPE_NUM_FLOAT                    0x00000007
#define NVC597_TEXHEAD_BL_X_SOURCE                                 MW(21:19)
#define NVC597_TEXHEAD_BL_X_SOURCE_IN_ZERO                         0x00000000
#define NVC597_TEXHEAD_BL_X_SOURCE_IN_R                            0x00000002
#define NVC597_TEXHEAD_BL_X_SOURCE_IN_G                            0x00000003
#define NVC597_TEXHEAD_BL_X_SOURCE_IN_B                            0x00000004
#define NVC597_TEXHEAD_BL_X_SOURCE_IN_A                            0x00000005
#define NVC597_TEXHEAD_BL_X_SOURCE_IN_ONE_INT                      0x00000006
#define NVC597_TEXHEAD_BL_X_SOURCE_IN_ONE_FLOAT                    0x00000007
#define NVC597_TEXHEAD_BL_Y_SOURCE                                 MW(24:22)
#define NVC597_TEXHEAD_BL_Y_SOURCE_IN_ZERO                         0x00000000
#define NVC597_TEXHEAD_BL_Y_SOURCE_IN_R                            0x00000002
#define NVC597_TEXHEAD_BL_Y_SOURCE_IN_G                            0x00000003
#define NVC597_TEXHEAD_BL_Y_SOURCE_IN_B                            0x00000004
#define NVC597_TEXHEAD_BL_Y_SOURCE_IN_A                            0x00000005
#define NVC597_TEXHEAD_BL_Y_SOURCE_IN_ONE_INT                      0x00000006
#define NVC597_TEXHEAD_BL_Y_SOURCE_IN_ONE_FLOAT                    0x00000007
#define NVC597_TEXHEAD_BL_Z_SOURCE                                 MW(27:25)
#define NVC597_TEXHEAD_BL_Z_SOURCE_IN_ZERO                         0x00000000
#define NVC597_TEXHEAD_BL_Z_SOURCE_IN_R                            0x00000002
#define NVC597_TEXHEAD_BL_Z_SOURCE_IN_G                            0x00000003
#define NVC597_TEXHEAD_BL_Z_SOURCE_IN_B                            0x00000004
#define NVC597_TEXHEAD_BL_Z_SOURCE_IN_A                            0x00000005
#define NVC597_TEXHEAD_BL_Z_SOURCE_IN_ONE_INT                      0x00000006
#define NVC597_TEXHEAD_BL_Z_SOURCE_IN_ONE_FLOAT                    0x00000007
#define NVC597_TEXHEAD_BL_W_SOURCE                                 MW(30:28)
#define NVC597_TEXHEAD_BL_W_SOURCE_IN_ZERO                         0x00000000
#define NVC597_TEXHEAD_BL_W_SOURCE_IN_R                            0x00000002
#define NVC597_TEXHEAD_BL_W_SOURCE_IN_G                            0x00000003
#define NVC597_TEXHEAD_BL_W_SOURCE_IN_B                            0x00000004
#define NVC597_TEXHEAD_BL_W_SOURCE_IN_A                            0x00000005
#define NVC597_TEXHEAD_BL_W_SOURCE_IN_ONE_INT                      0x00000006
#define NVC597_TEXHEAD_BL_W_SOURCE_IN_ONE_FLOAT                    0x00000007
#define NVC597_TEXHEAD_BL_PACK_COMPONENTS                          MW(31:31)
#define NVC597_TEXHEAD_BL_RESERVED1Y                               MW(36:32)
#define NVC597_TEXHEAD_BL_GOB_DEPTH_OFFSET                         MW(38:37)
#define NVC597_TEXHEAD_BL_RESERVED1X                               MW(40:39)
#define NVC597_TEXHEAD_BL_ADDRESS_BITS31TO9                        MW(63:41)
#define NVC597_TEXHEAD_BL_ADDRESS_BITS48TO32                       MW(80:64)
#define NVC597_TEXHEAD_BL_RESERVED_ADDRESS                         MW(84:81)
#define NVC597_TEXHEAD_BL_HEADER_VERSION                           MW(87:85)
#define NVC597_TEXHEAD_BL_HEADER_VERSION_SELECT_ONE_D_BUFFER       0x00000000
#define NVC597_TEXHEAD_BL_HEADER_VERSION_SELECT_PITCH_COLOR_KEY    0x00000001
#define NVC597_TEXHEAD_BL_HEADER_VERSION_SELECT_PITCH              0x00000002
#define NVC597_TEXHEAD_BL_HEADER_VERSION_SELECT_BLOCKLINEAR        0x00000003
#define NVC597_TEXHEAD_BL_HEADER_VERSION_SELECT_BLOCKLINEAR_COLOR_KEY 0x00000004
#define NVC597_TEXHEAD_BL_RESERVED_HEADER_VERSION                  MW(88:88)
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH             MW(92:89)
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_0 0x00000000
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_1 0x00000001
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_2 0x00000002
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_3 0x00000003
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_4 0x00000004
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_5 0x00000005
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_6 0x00000006
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_7 0x00000007
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_8 0x00000008
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_9 0x00000009
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_10 0x0000000a
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_11 0x0000000b
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_12 0x0000000c
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_13 0x0000000d
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_14 0x0000000e
#define NVC597_TEXHEAD_BL_RESOURCE_VIEW_COHERENCY_HASH_HASH_UNALIASED 0x0000000f
#define NVC597_TEXHEAD_BL_RESERVED2A                               MW(95:93)
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_WIDTH                     MW(98:96)
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_WIDTH_ONE_GOB             0x00000000
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_HEIGHT                    MW(101:99)
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_HEIGHT_ONE_GOB            0x00000000
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_HEIGHT_TWO_GOBS           0x00000001
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_HEIGHT_FOUR_GOBS          0x00000002
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_HEIGHT_EIGHT_GOBS         0x00000003
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_HEIGHT_SIXTEEN_GOBS       0x00000004
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_HEIGHT_THIRTYTWO_GOBS     0x00000005
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_DEPTH                     MW(104:102)
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_DEPTH_ONE_GOB             0x00000000
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_DEPTH_TWO_GOBS            0x00000001
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_DEPTH_FOUR_GOBS           0x00000002
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_DEPTH_EIGHT_GOBS          0x00000003
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_DEPTH_SIXTEEN_GOBS        0x00000004
#define NVC597_TEXHEAD_BL_GOBS_PER_BLOCK_DEPTH_THIRTYTWO_GOBS      0x00000005
#define NVC597_TEXHEAD_BL_RESERVED3Y                               MW(105:105)
#define NVC597_TEXHEAD_BL_TILE_WIDTH_IN_GOBS                       MW(108:106)
#define NVC597_TEXHEAD_BL_TILE_WIDTH_IN_GOBS_ONE_GOB               0x00000000
#define NVC597_TEXHEAD_BL_TILE_WIDTH_IN_GOBS_TWO_GOBS              0x00000001
#define NVC597_TEXHEAD_BL_TILE_WIDTH_IN_GOBS_FOUR_GOBS             0x00000002
#define NVC597_TEXHEAD_BL_TILE_WIDTH_IN_GOBS_EIGHT_GOBS            0x00000003
#define NVC597_TEXHEAD_BL_TILE_WIDTH_IN_GOBS_SIXTEEN_GOBS          0x00000004
#define NVC597_TEXHEAD_BL_TILE_WIDTH_IN_GOBS_THIRTYTWO_GOBS        0x00000005
#define NVC597_TEXHEAD_BL_GOB3D                                    MW(109:109)
#define NVC597_TEXHEAD_BL_RESERVED3Z                               MW(111:110)
#define NVC597_TEXHEAD_BL_LOD_ANISO_QUALITY2                       MW(112:112)
#define NVC597_TEXHEAD_BL_LOD_ANISO_QUALITY                        MW(113:113)
#define NVC597_TEXHEAD_BL_LOD_ANISO_QUALITY_LOD_QUALITY_LOW        0x00000000
#define NVC597_TEXHEAD_BL_LOD_ANISO_QUALITY_LOD_QUALITY_HIGH       0x00000001
#define NVC597_TEXHEAD_BL_LOD_ISO_QUALITY                          MW(114:114)
#define NVC597_TEXHEAD_BL_LOD_ISO_QUALITY_LOD_QUALITY_LOW          0x00000000
#define NVC597_TEXHEAD_BL_LOD_ISO_QUALITY_LOD_QUALITY_HIGH         0x00000001
#define NVC597_TEXHEAD_BL_ANISO_COARSE_SPREAD_MODIFIER             MW(116:115)
#define NVC597_TEXHEAD_BL_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_NONE 0x00000000
#define NVC597_TEXHEAD_BL_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_ONE 0x00000001
#define NVC597_TEXHEAD_BL_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_TWO 0x00000002
#define NVC597_TEXHEAD_BL_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_SQRT 0x00000003
#define NVC597_TEXHEAD_BL_ANISO_SPREAD_SCALE                       MW(121:117)
#define NVC597_TEXHEAD_BL_USE_HEADER_OPT_CONTROL                   MW(122:122)
#define NVC597_TEXHEAD_BL_DEPTH_TEXTURE                            MW(123:123)
#define NVC597_TEXHEAD_BL_MAX_MIP_LEVEL                            MW(127:124)
#define NVC597_TEXHEAD_BL_WIDTH_MINUS_ONE                          MW(144:128)
#define NVC597_TEXHEAD_BL_DEPTH_MINUS_ONE_BIT14                    MW(145:145)
#define NVC597_TEXHEAD_BL_HEIGHT_MINUS_ONE_BIT16                   MW(146:146)
#define NVC597_TEXHEAD_BL_ANISO_SPREAD_MAX_LOG2                    MW(149:147)
#define NVC597_TEXHEAD_BL_S_R_G_B_CONVERSION                       MW(150:150)
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE                             MW(154:151)
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_ONE_D                       0x00000000
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_TWO_D                       0x00000001
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_THREE_D                     0x00000002
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_CUBEMAP                     0x00000003
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_ONE_D_ARRAY                 0x00000004
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_TWO_D_ARRAY                 0x00000005
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_ONE_D_BUFFER                0x00000006
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_TWO_D_NO_MIPMAP             0x00000007
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_CUBEMAP_ARRAY               0x00000008
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_HTEX_TWOD                   0x0000000a
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_HTEX_THREE_D                0x0000000b
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_HTEX_TWOD_ARRAY             0x0000000e
#define NVC597_TEXHEAD_BL_TEXTURE_TYPE_TT_BIT_FIELD_SIZE           0x0000000f
#define NVC597_TEXHEAD_BL_SECTOR_PROMOTION                         MW(156:155)
#define NVC597_TEXHEAD_BL_SECTOR_PROMOTION_NO_PROMOTION            0x00000000
#define NVC597_TEXHEAD_BL_SECTOR_PROMOTION_PROMOTE_TO_2_V          0x00000001
#define NVC597_TEXHEAD_BL_SECTOR_PROMOTION_PROMOTE_TO_2_H          0x00000002
#define NVC597_TEXHEAD_BL_SECTOR_PROMOTION_PROMOTE_TO_4            0x00000003
#define NVC597_TEXHEAD_BL_BORDER_SIZE                              MW(159:157)
#define NVC597_TEXHEAD_BL_BORDER_SIZE_BORDER_SIZE_ONE              0x00000000
#define NVC597_TEXHEAD_BL_BORDER_SIZE_BORDER_SIZE_TWO              0x00000001
#define NVC597_TEXHEAD_BL_BORDER_SIZE_BORDER_SIZE_FOUR             0x00000002
#define NVC597_TEXHEAD_BL_BORDER_SIZE_BORDER_SIZE_EIGHT            0x00000003
#define NVC597_TEXHEAD_BL_BORDER_SIZE_BORDER_SAMPLER_COLOR         0x00000007
#define NVC597_TEXHEAD_BL_HEIGHT_MINUS_ONE                         MW(175:160)
#define NVC597_TEXHEAD_BL_DEPTH_MINUS_ONE                          MW(189:176)
#define NVC597_TEXHEAD_BL_RESERVED5A                               MW(190:190)
#define NVC597_TEXHEAD_BL_NORMALIZED_COORDS                        MW(191:191)
#define NVC597_TEXHEAD_BL_RESERVED6Y                               MW(192:192)
#define NVC597_TEXHEAD_BL_TRILIN_OPT                               MW(197:193)
#define NVC597_TEXHEAD_BL_MIP_LOD_BIAS                             MW(210:198)
#define NVC597_TEXHEAD_BL_ANISO_BIAS                               MW(214:211)
#define NVC597_TEXHEAD_BL_ANISO_FINE_SPREAD_FUNC                   MW(216:215)
#define NVC597_TEXHEAD_BL_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_HALF  0x00000000
#define NVC597_TEXHEAD_BL_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_ONE   0x00000001
#define NVC597_TEXHEAD_BL_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_TWO   0x00000002
#define NVC597_TEXHEAD_BL_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_MAX   0x00000003
#define NVC597_TEXHEAD_BL_ANISO_COARSE_SPREAD_FUNC                 MW(218:217)
#define NVC597_TEXHEAD_BL_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_HALF 0x00000000
#define NVC597_TEXHEAD_BL_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_ONE 0x00000001
#define NVC597_TEXHEAD_BL_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_TWO 0x00000002
#define NVC597_TEXHEAD_BL_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_MAX 0x00000003
#define NVC597_TEXHEAD_BL_MAX_ANISOTROPY                           MW(221:219)
#define NVC597_TEXHEAD_BL_MAX_ANISOTROPY_ANISO_1_TO_1              0x00000000
#define NVC597_TEXHEAD_BL_MAX_ANISOTROPY_ANISO_2_TO_1              0x00000001
#define NVC597_TEXHEAD_BL_MAX_ANISOTROPY_ANISO_4_TO_1              0x00000002
#define NVC597_TEXHEAD_BL_MAX_ANISOTROPY_ANISO_6_TO_1              0x00000003
#define NVC597_TEXHEAD_BL_MAX_ANISOTROPY_ANISO_8_TO_1              0x00000004
#define NVC597_TEXHEAD_BL_MAX_ANISOTROPY_ANISO_10_TO_1             0x00000005
#define NVC597_TEXHEAD_BL_MAX_ANISOTROPY_ANISO_12_TO_1             0x00000006
#define NVC597_TEXHEAD_BL_MAX_ANISOTROPY_ANISO_16_TO_1             0x00000007
#define NVC597_TEXHEAD_BL_ANISO_FINE_SPREAD_MODIFIER               MW(223:222)
#define NVC597_TEXHEAD_BL_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_NONE 0x00000000
#define NVC597_TEXHEAD_BL_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_ONE 0x00000001
#define NVC597_TEXHEAD_BL_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_TWO 0x00000002
#define NVC597_TEXHEAD_BL_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_SQRT 0x00000003
#define NVC597_TEXHEAD_BL_RES_VIEW_MIN_MIP_LEVEL                   MW(227:224)
#define NVC597_TEXHEAD_BL_RES_VIEW_MAX_MIP_LEVEL                   MW(231:228)
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT                       MW(235:232)
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_1X1              0x00000000
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_2X1              0x00000001
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_2X2              0x00000002
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_4X2              0x00000003
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_4X2_D3D          0x00000004
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_2X1_D3D          0x00000005
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_4X4              0x00000006
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_2X2_VC_4         0x00000008
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_2X2_VC_12        0x00000009
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_4X2_VC_8         0x0000000a
#define NVC597_TEXHEAD_BL_MULTI_SAMPLE_COUNT_MODE_4X2_VC_24        0x0000000b
#define NVC597_TEXHEAD_BL_MIN_LOD_CLAMP                            MW(247:236)
#define NVC597_TEXHEAD_BL_RESERVED7Y                               MW(255:248)


/*
** Texture Header State Blocklinear Color Key
 */

#define NVC597_TEXHEAD_BLCK_COMPONENTS                             MW(6:0)
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_INVALID               0x00000000
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_R32_G32_B32_A32       0x00000001
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_R32_G32_B32           0x00000002
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_R16_G16_B16_A16       0x00000003
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_R32_G32               0x00000004
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_R32_B24G8             0x00000005
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_X8B8G8R8              0x00000007
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_A8B8G8R8              0x00000008
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_A2B10G10R10           0x00000009
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_R16_G16               0x0000000c
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_G8R24                 0x0000000d
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_G24R8                 0x0000000e
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_R32                   0x0000000f
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_A4B4G4R4              0x00000012
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_A5B5G5R1              0x00000013
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_A1B5G5R5              0x00000014
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_B5G6R5                0x00000015
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_B6G5R5                0x00000016
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_G8R8                  0x00000018
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_R16                   0x0000001b
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_Y8_VIDEO              0x0000001c
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_R8                    0x0000001d
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_G4R4                  0x0000001e
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_R1                    0x0000001f
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_E5B9G9R9_SHAREDEXP    0x00000020
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_BF10GF11RF11          0x00000021
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_G8B8G8R8              0x00000022
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_B8G8R8G8              0x00000023
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_DXT1                  0x00000024
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_DXT23                 0x00000025
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_DXT45                 0x00000026
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_DXN1                  0x00000027
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_DXN2                  0x00000028
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_BC6H_SF16             0x00000010
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_BC6H_UF16             0x00000011
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_BC7U                  0x00000017
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ETC2_RGB              0x00000006
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ETC2_RGB_PTA          0x0000000a
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ETC2_RGBA             0x0000000b
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_EAC                   0x00000019
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_EACX2                 0x0000001a
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_Z24S8                 0x00000029
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_X8Z24                 0x0000002a
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_S8Z24                 0x0000002b
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_X4V4Z24__COV4R4V      0x0000002c
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_X4V4Z24__COV8R8V      0x0000002d
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_V8Z24__COV4R12V       0x0000002e
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ZF32                  0x0000002f
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ZF32_X24S8            0x00000030
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_X8Z24_X20V4S8__COV4R4V 0x00000031
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_X8Z24_X20V4S8__COV8R8V 0x00000032
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ZF32_X20V4X8__COV4R4V 0x00000033
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ZF32_X20V4X8__COV8R8V 0x00000034
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ZF32_X20V4S8__COV4R4V 0x00000035
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ZF32_X20V4S8__COV8R8V 0x00000036
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_X8Z24_X16V8S8__COV4R12V 0x00000037
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ZF32_X16V8X8__COV4R12V 0x00000038
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ZF32_X16V8S8__COV4R12V 0x00000039
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_Z16                   0x0000003a
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_V8Z24__COV8R24V       0x0000003b
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_X8Z24_X16V8S8__COV8R24V 0x0000003c
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ZF32_X16V8X8__COV8R24V 0x0000003d
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ZF32_X16V8S8__COV8R24V 0x0000003e
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_4X4           0x00000040
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_5X4           0x00000050
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_5X5           0x00000041
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_6X5           0x00000051
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_6X6           0x00000042
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_8X5           0x00000055
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_8X6           0x00000052
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_8X8           0x00000044
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_10X5          0x00000056
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_10X6          0x00000057
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_10X8          0x00000053
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_10X10         0x00000045
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_12X10         0x00000054
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_ASTC_2D_12X12         0x00000046
#define NVC597_TEXHEAD_BLCK_COMPONENTS_SIZES_CS_BITFIELD_SIZE      0x0000007f
#define NVC597_TEXHEAD_BLCK_R_DATA_TYPE                            MW(9:7)
#define NVC597_TEXHEAD_BLCK_R_DATA_TYPE_NUM_SNORM                  0x00000001
#define NVC597_TEXHEAD_BLCK_R_DATA_TYPE_NUM_UNORM                  0x00000002
#define NVC597_TEXHEAD_BLCK_R_DATA_TYPE_NUM_SINT                   0x00000003
#define NVC597_TEXHEAD_BLCK_R_DATA_TYPE_NUM_UINT                   0x00000004
#define NVC597_TEXHEAD_BLCK_R_DATA_TYPE_NUM_SNORM_FORCE_FP16       0x00000005
#define NVC597_TEXHEAD_BLCK_R_DATA_TYPE_NUM_UNORM_FORCE_FP16       0x00000006
#define NVC597_TEXHEAD_BLCK_R_DATA_TYPE_NUM_FLOAT                  0x00000007
#define NVC597_TEXHEAD_BLCK_G_DATA_TYPE                            MW(12:10)
#define NVC597_TEXHEAD_BLCK_G_DATA_TYPE_NUM_SNORM                  0x00000001
#define NVC597_TEXHEAD_BLCK_G_DATA_TYPE_NUM_UNORM                  0x00000002
#define NVC597_TEXHEAD_BLCK_G_DATA_TYPE_NUM_SINT                   0x00000003
#define NVC597_TEXHEAD_BLCK_G_DATA_TYPE_NUM_UINT                   0x00000004
#define NVC597_TEXHEAD_BLCK_G_DATA_TYPE_NUM_SNORM_FORCE_FP16       0x00000005
#define NVC597_TEXHEAD_BLCK_G_DATA_TYPE_NUM_UNORM_FORCE_FP16       0x00000006
#define NVC597_TEXHEAD_BLCK_G_DATA_TYPE_NUM_FLOAT                  0x00000007
#define NVC597_TEXHEAD_BLCK_B_DATA_TYPE                            MW(15:13)
#define NVC597_TEXHEAD_BLCK_B_DATA_TYPE_NUM_SNORM                  0x00000001
#define NVC597_TEXHEAD_BLCK_B_DATA_TYPE_NUM_UNORM                  0x00000002
#define NVC597_TEXHEAD_BLCK_B_DATA_TYPE_NUM_SINT                   0x00000003
#define NVC597_TEXHEAD_BLCK_B_DATA_TYPE_NUM_UINT                   0x00000004
#define NVC597_TEXHEAD_BLCK_B_DATA_TYPE_NUM_SNORM_FORCE_FP16       0x00000005
#define NVC597_TEXHEAD_BLCK_B_DATA_TYPE_NUM_UNORM_FORCE_FP16       0x00000006
#define NVC597_TEXHEAD_BLCK_B_DATA_TYPE_NUM_FLOAT                  0x00000007
#define NVC597_TEXHEAD_BLCK_A_DATA_TYPE                            MW(18:16)
#define NVC597_TEXHEAD_BLCK_A_DATA_TYPE_NUM_SNORM                  0x00000001
#define NVC597_TEXHEAD_BLCK_A_DATA_TYPE_NUM_UNORM                  0x00000002
#define NVC597_TEXHEAD_BLCK_A_DATA_TYPE_NUM_SINT                   0x00000003
#define NVC597_TEXHEAD_BLCK_A_DATA_TYPE_NUM_UINT                   0x00000004
#define NVC597_TEXHEAD_BLCK_A_DATA_TYPE_NUM_SNORM_FORCE_FP16       0x00000005
#define NVC597_TEXHEAD_BLCK_A_DATA_TYPE_NUM_UNORM_FORCE_FP16       0x00000006
#define NVC597_TEXHEAD_BLCK_A_DATA_TYPE_NUM_FLOAT                  0x00000007
#define NVC597_TEXHEAD_BLCK_X_SOURCE                               MW(21:19)
#define NVC597_TEXHEAD_BLCK_X_SOURCE_IN_ZERO                       0x00000000
#define NVC597_TEXHEAD_BLCK_X_SOURCE_IN_R                          0x00000002
#define NVC597_TEXHEAD_BLCK_X_SOURCE_IN_G                          0x00000003
#define NVC597_TEXHEAD_BLCK_X_SOURCE_IN_B                          0x00000004
#define NVC597_TEXHEAD_BLCK_X_SOURCE_IN_A                          0x00000005
#define NVC597_TEXHEAD_BLCK_X_SOURCE_IN_ONE_INT                    0x00000006
#define NVC597_TEXHEAD_BLCK_X_SOURCE_IN_ONE_FLOAT                  0x00000007
#define NVC597_TEXHEAD_BLCK_Y_SOURCE                               MW(24:22)
#define NVC597_TEXHEAD_BLCK_Y_SOURCE_IN_ZERO                       0x00000000
#define NVC597_TEXHEAD_BLCK_Y_SOURCE_IN_R                          0x00000002
#define NVC597_TEXHEAD_BLCK_Y_SOURCE_IN_G                          0x00000003
#define NVC597_TEXHEAD_BLCK_Y_SOURCE_IN_B                          0x00000004
#define NVC597_TEXHEAD_BLCK_Y_SOURCE_IN_A                          0x00000005
#define NVC597_TEXHEAD_BLCK_Y_SOURCE_IN_ONE_INT                    0x00000006
#define NVC597_TEXHEAD_BLCK_Y_SOURCE_IN_ONE_FLOAT                  0x00000007
#define NVC597_TEXHEAD_BLCK_Z_SOURCE                               MW(27:25)
#define NVC597_TEXHEAD_BLCK_Z_SOURCE_IN_ZERO                       0x00000000
#define NVC597_TEXHEAD_BLCK_Z_SOURCE_IN_R                          0x00000002
#define NVC597_TEXHEAD_BLCK_Z_SOURCE_IN_G                          0x00000003
#define NVC597_TEXHEAD_BLCK_Z_SOURCE_IN_B                          0x00000004
#define NVC597_TEXHEAD_BLCK_Z_SOURCE_IN_A                          0x00000005
#define NVC597_TEXHEAD_BLCK_Z_SOURCE_IN_ONE_INT                    0x00000006
#define NVC597_TEXHEAD_BLCK_Z_SOURCE_IN_ONE_FLOAT                  0x00000007
#define NVC597_TEXHEAD_BLCK_W_SOURCE                               MW(30:28)
#define NVC597_TEXHEAD_BLCK_W_SOURCE_IN_ZERO                       0x00000000
#define NVC597_TEXHEAD_BLCK_W_SOURCE_IN_R                          0x00000002
#define NVC597_TEXHEAD_BLCK_W_SOURCE_IN_G                          0x00000003
#define NVC597_TEXHEAD_BLCK_W_SOURCE_IN_B                          0x00000004
#define NVC597_TEXHEAD_BLCK_W_SOURCE_IN_A                          0x00000005
#define NVC597_TEXHEAD_BLCK_W_SOURCE_IN_ONE_INT                    0x00000006
#define NVC597_TEXHEAD_BLCK_W_SOURCE_IN_ONE_FLOAT                  0x00000007
#define NVC597_TEXHEAD_BLCK_PACK_COMPONENTS                        MW(31:31)
#define NVC597_TEXHEAD_BLCK_RESERVED1Y                             MW(36:32)
#define NVC597_TEXHEAD_BLCK_GOB_DEPTH_OFFSET                       MW(38:37)
#define NVC597_TEXHEAD_BLCK_RESERVED1X                             MW(40:39)
#define NVC597_TEXHEAD_BLCK_ADDRESS_BITS31TO9                      MW(63:41)
#define NVC597_TEXHEAD_BLCK_ADDRESS_BITS48TO32                     MW(80:64)
#define NVC597_TEXHEAD_BLCK_RESERVED_ADDRESS                       MW(84:81)
#define NVC597_TEXHEAD_BLCK_HEADER_VERSION                         MW(87:85)
#define NVC597_TEXHEAD_BLCK_HEADER_VERSION_SELECT_ONE_D_BUFFER     0x00000000
#define NVC597_TEXHEAD_BLCK_HEADER_VERSION_SELECT_PITCH_COLOR_KEY  0x00000001
#define NVC597_TEXHEAD_BLCK_HEADER_VERSION_SELECT_PITCH            0x00000002
#define NVC597_TEXHEAD_BLCK_HEADER_VERSION_SELECT_BLOCKLINEAR      0x00000003
#define NVC597_TEXHEAD_BLCK_HEADER_VERSION_SELECT_BLOCKLINEAR_COLOR_KEY 0x00000004
#define NVC597_TEXHEAD_BLCK_RESERVED_HEADER_VERSION                MW(88:88)
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH           MW(92:89)
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_0 0x00000000
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_1 0x00000001
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_2 0x00000002
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_3 0x00000003
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_4 0x00000004
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_5 0x00000005
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_6 0x00000006
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_7 0x00000007
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_8 0x00000008
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_9 0x00000009
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_10 0x0000000a
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_11 0x0000000b
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_12 0x0000000c
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_13 0x0000000d
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_14 0x0000000e
#define NVC597_TEXHEAD_BLCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_UNALIASED 0x0000000f
#define NVC597_TEXHEAD_BLCK_RESERVED2A                             MW(95:93)
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_WIDTH                   MW(98:96)
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_WIDTH_ONE_GOB           0x00000000
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_HEIGHT                  MW(101:99)
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_HEIGHT_ONE_GOB          0x00000000
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_HEIGHT_TWO_GOBS         0x00000001
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_HEIGHT_FOUR_GOBS        0x00000002
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_HEIGHT_EIGHT_GOBS       0x00000003
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_HEIGHT_SIXTEEN_GOBS     0x00000004
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_HEIGHT_THIRTYTWO_GOBS   0x00000005
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_DEPTH                   MW(104:102)
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_DEPTH_ONE_GOB           0x00000000
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_DEPTH_TWO_GOBS          0x00000001
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_DEPTH_FOUR_GOBS         0x00000002
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_DEPTH_EIGHT_GOBS        0x00000003
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_DEPTH_SIXTEEN_GOBS      0x00000004
#define NVC597_TEXHEAD_BLCK_GOBS_PER_BLOCK_DEPTH_THIRTYTWO_GOBS    0x00000005
#define NVC597_TEXHEAD_BLCK_RESERVED3Y                             MW(105:105)
#define NVC597_TEXHEAD_BLCK_TILE_WIDTH_IN_GOBS                     MW(108:106)
#define NVC597_TEXHEAD_BLCK_TILE_WIDTH_IN_GOBS_ONE_GOB             0x00000000
#define NVC597_TEXHEAD_BLCK_TILE_WIDTH_IN_GOBS_TWO_GOBS            0x00000001
#define NVC597_TEXHEAD_BLCK_TILE_WIDTH_IN_GOBS_FOUR_GOBS           0x00000002
#define NVC597_TEXHEAD_BLCK_TILE_WIDTH_IN_GOBS_EIGHT_GOBS          0x00000003
#define NVC597_TEXHEAD_BLCK_TILE_WIDTH_IN_GOBS_SIXTEEN_GOBS        0x00000004
#define NVC597_TEXHEAD_BLCK_TILE_WIDTH_IN_GOBS_THIRTYTWO_GOBS      0x00000005
#define NVC597_TEXHEAD_BLCK_GOB3D                                  MW(109:109)
#define NVC597_TEXHEAD_BLCK_RESERVED3Z                             MW(111:110)
#define NVC597_TEXHEAD_BLCK_LOD_ANISO_QUALITY2                     MW(112:112)
#define NVC597_TEXHEAD_BLCK_LOD_ANISO_QUALITY                      MW(113:113)
#define NVC597_TEXHEAD_BLCK_LOD_ANISO_QUALITY_LOD_QUALITY_LOW      0x00000000
#define NVC597_TEXHEAD_BLCK_LOD_ANISO_QUALITY_LOD_QUALITY_HIGH     0x00000001
#define NVC597_TEXHEAD_BLCK_LOD_ISO_QUALITY                        MW(114:114)
#define NVC597_TEXHEAD_BLCK_LOD_ISO_QUALITY_LOD_QUALITY_LOW        0x00000000
#define NVC597_TEXHEAD_BLCK_LOD_ISO_QUALITY_LOD_QUALITY_HIGH       0x00000001
#define NVC597_TEXHEAD_BLCK_ANISO_COARSE_SPREAD_MODIFIER           MW(116:115)
#define NVC597_TEXHEAD_BLCK_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_NONE 0x00000000
#define NVC597_TEXHEAD_BLCK_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_ONE 0x00000001
#define NVC597_TEXHEAD_BLCK_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_TWO 0x00000002
#define NVC597_TEXHEAD_BLCK_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_SQRT 0x00000003
#define NVC597_TEXHEAD_BLCK_ANISO_SPREAD_SCALE                     MW(121:117)
#define NVC597_TEXHEAD_BLCK_USE_HEADER_OPT_CONTROL                 MW(122:122)
#define NVC597_TEXHEAD_BLCK_DEPTH_TEXTURE                          MW(123:123)
#define NVC597_TEXHEAD_BLCK_MAX_MIP_LEVEL                          MW(127:124)
#define NVC597_TEXHEAD_BLCK_WIDTH_MINUS_ONE                        MW(144:128)
#define NVC597_TEXHEAD_BLCK_DEPTH_MINUS_ONE_BIT14                  MW(145:145)
#define NVC597_TEXHEAD_BLCK_HEIGHT_MINUS_ONE_BIT16                 MW(146:146)
#define NVC597_TEXHEAD_BLCK_ANISO_SPREAD_MAX_LOG2                  MW(149:147)
#define NVC597_TEXHEAD_BLCK_S_R_G_B_CONVERSION                     MW(150:150)
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE                           MW(154:151)
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_ONE_D                     0x00000000
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_TWO_D                     0x00000001
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_THREE_D                   0x00000002
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_CUBEMAP                   0x00000003
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_ONE_D_ARRAY               0x00000004
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_TWO_D_ARRAY               0x00000005
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_ONE_D_BUFFER              0x00000006
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_TWO_D_NO_MIPMAP           0x00000007
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_CUBEMAP_ARRAY             0x00000008
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_HTEX_TWOD                 0x0000000a
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_HTEX_THREE_D              0x0000000b
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_HTEX_TWOD_ARRAY           0x0000000e
#define NVC597_TEXHEAD_BLCK_TEXTURE_TYPE_TT_BIT_FIELD_SIZE         0x0000000f
#define NVC597_TEXHEAD_BLCK_SECTOR_PROMOTION                       MW(156:155)
#define NVC597_TEXHEAD_BLCK_SECTOR_PROMOTION_NO_PROMOTION          0x00000000
#define NVC597_TEXHEAD_BLCK_SECTOR_PROMOTION_PROMOTE_TO_2_V        0x00000001
#define NVC597_TEXHEAD_BLCK_SECTOR_PROMOTION_PROMOTE_TO_2_H        0x00000002
#define NVC597_TEXHEAD_BLCK_SECTOR_PROMOTION_PROMOTE_TO_4          0x00000003
#define NVC597_TEXHEAD_BLCK_BORDER_SIZE                            MW(159:157)
#define NVC597_TEXHEAD_BLCK_BORDER_SIZE_BORDER_SIZE_ONE            0x00000000
#define NVC597_TEXHEAD_BLCK_BORDER_SIZE_BORDER_SIZE_TWO            0x00000001
#define NVC597_TEXHEAD_BLCK_BORDER_SIZE_BORDER_SIZE_FOUR           0x00000002
#define NVC597_TEXHEAD_BLCK_BORDER_SIZE_BORDER_SIZE_EIGHT          0x00000003
#define NVC597_TEXHEAD_BLCK_BORDER_SIZE_BORDER_SAMPLER_COLOR       0x00000007
#define NVC597_TEXHEAD_BLCK_HEIGHT_MINUS_ONE                       MW(175:160)
#define NVC597_TEXHEAD_BLCK_DEPTH_MINUS_ONE                        MW(189:176)
#define NVC597_TEXHEAD_BLCK_RESERVED5A                             MW(190:190)
#define NVC597_TEXHEAD_BLCK_NORMALIZED_COORDS                      MW(191:191)
#define NVC597_TEXHEAD_BLCK_COLOR_KEY_OP                           MW(192:192)
#define NVC597_TEXHEAD_BLCK_TRILIN_OPT                             MW(197:193)
#define NVC597_TEXHEAD_BLCK_MIP_LOD_BIAS                           MW(210:198)
#define NVC597_TEXHEAD_BLCK_ANISO_BIAS                             MW(214:211)
#define NVC597_TEXHEAD_BLCK_ANISO_FINE_SPREAD_FUNC                 MW(216:215)
#define NVC597_TEXHEAD_BLCK_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_HALF 0x00000000
#define NVC597_TEXHEAD_BLCK_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_ONE 0x00000001
#define NVC597_TEXHEAD_BLCK_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_TWO 0x00000002
#define NVC597_TEXHEAD_BLCK_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_MAX 0x00000003
#define NVC597_TEXHEAD_BLCK_ANISO_COARSE_SPREAD_FUNC               MW(218:217)
#define NVC597_TEXHEAD_BLCK_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_HALF 0x00000000
#define NVC597_TEXHEAD_BLCK_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_ONE 0x00000001
#define NVC597_TEXHEAD_BLCK_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_TWO 0x00000002
#define NVC597_TEXHEAD_BLCK_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_MAX 0x00000003
#define NVC597_TEXHEAD_BLCK_MAX_ANISOTROPY                         MW(221:219)
#define NVC597_TEXHEAD_BLCK_MAX_ANISOTROPY_ANISO_1_TO_1            0x00000000
#define NVC597_TEXHEAD_BLCK_MAX_ANISOTROPY_ANISO_2_TO_1            0x00000001
#define NVC597_TEXHEAD_BLCK_MAX_ANISOTROPY_ANISO_4_TO_1            0x00000002
#define NVC597_TEXHEAD_BLCK_MAX_ANISOTROPY_ANISO_6_TO_1            0x00000003
#define NVC597_TEXHEAD_BLCK_MAX_ANISOTROPY_ANISO_8_TO_1            0x00000004
#define NVC597_TEXHEAD_BLCK_MAX_ANISOTROPY_ANISO_10_TO_1           0x00000005
#define NVC597_TEXHEAD_BLCK_MAX_ANISOTROPY_ANISO_12_TO_1           0x00000006
#define NVC597_TEXHEAD_BLCK_MAX_ANISOTROPY_ANISO_16_TO_1           0x00000007
#define NVC597_TEXHEAD_BLCK_ANISO_FINE_SPREAD_MODIFIER             MW(223:222)
#define NVC597_TEXHEAD_BLCK_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_NONE 0x00000000
#define NVC597_TEXHEAD_BLCK_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_ONE 0x00000001
#define NVC597_TEXHEAD_BLCK_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_TWO 0x00000002
#define NVC597_TEXHEAD_BLCK_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_SQRT 0x00000003
#define NVC597_TEXHEAD_BLCK_COLOR_KEY_VALUE                        MW(255:224)


/*
** Texture Header State One-D Buffer
 */

#define NVC597_TEXHEAD_1D_COMPONENTS                               MW(6:0)
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_INVALID                 0x00000000
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_R32_G32_B32_A32         0x00000001
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_R32_G32_B32             0x00000002
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_R16_G16_B16_A16         0x00000003
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_R32_G32                 0x00000004
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_R32_B24G8               0x00000005
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_X8B8G8R8                0x00000007
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_A8B8G8R8                0x00000008
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_A2B10G10R10             0x00000009
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_R16_G16                 0x0000000c
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_G8R24                   0x0000000d
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_G24R8                   0x0000000e
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_R32                     0x0000000f
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_A4B4G4R4                0x00000012
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_A5B5G5R1                0x00000013
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_A1B5G5R5                0x00000014
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_B5G6R5                  0x00000015
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_B6G5R5                  0x00000016
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_G8R8                    0x00000018
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_R16                     0x0000001b
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_Y8_VIDEO                0x0000001c
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_R8                      0x0000001d
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_G4R4                    0x0000001e
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_R1                      0x0000001f
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_E5B9G9R9_SHAREDEXP      0x00000020
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_BF10GF11RF11            0x00000021
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_G8B8G8R8                0x00000022
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_B8G8R8G8                0x00000023
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_DXT1                    0x00000024
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_DXT23                   0x00000025
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_DXT45                   0x00000026
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_DXN1                    0x00000027
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_DXN2                    0x00000028
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_BC6H_SF16               0x00000010
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_BC6H_UF16               0x00000011
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_BC7U                    0x00000017
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ETC2_RGB                0x00000006
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ETC2_RGB_PTA            0x0000000a
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ETC2_RGBA               0x0000000b
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_EAC                     0x00000019
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_EACX2                   0x0000001a
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_Z24S8                   0x00000029
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_X8Z24                   0x0000002a
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_S8Z24                   0x0000002b
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_X4V4Z24__COV4R4V        0x0000002c
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_X4V4Z24__COV8R8V        0x0000002d
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_V8Z24__COV4R12V         0x0000002e
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ZF32                    0x0000002f
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ZF32_X24S8              0x00000030
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_X8Z24_X20V4S8__COV4R4V  0x00000031
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_X8Z24_X20V4S8__COV8R8V  0x00000032
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ZF32_X20V4X8__COV4R4V   0x00000033
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ZF32_X20V4X8__COV8R8V   0x00000034
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ZF32_X20V4S8__COV4R4V   0x00000035
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ZF32_X20V4S8__COV8R8V   0x00000036
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_X8Z24_X16V8S8__COV4R12V 0x00000037
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ZF32_X16V8X8__COV4R12V  0x00000038
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ZF32_X16V8S8__COV4R12V  0x00000039
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_Z16                     0x0000003a
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_V8Z24__COV8R24V         0x0000003b
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_X8Z24_X16V8S8__COV8R24V 0x0000003c
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ZF32_X16V8X8__COV8R24V  0x0000003d
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ZF32_X16V8S8__COV8R24V  0x0000003e
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_4X4             0x00000040
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_5X4             0x00000050
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_5X5             0x00000041
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_6X5             0x00000051
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_6X6             0x00000042
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_8X5             0x00000055
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_8X6             0x00000052
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_8X8             0x00000044
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_10X5            0x00000056
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_10X6            0x00000057
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_10X8            0x00000053
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_10X10           0x00000045
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_12X10           0x00000054
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_ASTC_2D_12X12           0x00000046
#define NVC597_TEXHEAD_1D_COMPONENTS_SIZES_CS_BITFIELD_SIZE        0x0000007f
#define NVC597_TEXHEAD_1D_R_DATA_TYPE                              MW(9:7)
#define NVC597_TEXHEAD_1D_R_DATA_TYPE_NUM_SNORM                    0x00000001
#define NVC597_TEXHEAD_1D_R_DATA_TYPE_NUM_UNORM                    0x00000002
#define NVC597_TEXHEAD_1D_R_DATA_TYPE_NUM_SINT                     0x00000003
#define NVC597_TEXHEAD_1D_R_DATA_TYPE_NUM_UINT                     0x00000004
#define NVC597_TEXHEAD_1D_R_DATA_TYPE_NUM_SNORM_FORCE_FP16         0x00000005
#define NVC597_TEXHEAD_1D_R_DATA_TYPE_NUM_UNORM_FORCE_FP16         0x00000006
#define NVC597_TEXHEAD_1D_R_DATA_TYPE_NUM_FLOAT                    0x00000007
#define NVC597_TEXHEAD_1D_G_DATA_TYPE                              MW(12:10)
#define NVC597_TEXHEAD_1D_G_DATA_TYPE_NUM_SNORM                    0x00000001
#define NVC597_TEXHEAD_1D_G_DATA_TYPE_NUM_UNORM                    0x00000002
#define NVC597_TEXHEAD_1D_G_DATA_TYPE_NUM_SINT                     0x00000003
#define NVC597_TEXHEAD_1D_G_DATA_TYPE_NUM_UINT                     0x00000004
#define NVC597_TEXHEAD_1D_G_DATA_TYPE_NUM_SNORM_FORCE_FP16         0x00000005
#define NVC597_TEXHEAD_1D_G_DATA_TYPE_NUM_UNORM_FORCE_FP16         0x00000006
#define NVC597_TEXHEAD_1D_G_DATA_TYPE_NUM_FLOAT                    0x00000007
#define NVC597_TEXHEAD_1D_B_DATA_TYPE                              MW(15:13)
#define NVC597_TEXHEAD_1D_B_DATA_TYPE_NUM_SNORM                    0x00000001
#define NVC597_TEXHEAD_1D_B_DATA_TYPE_NUM_UNORM                    0x00000002
#define NVC597_TEXHEAD_1D_B_DATA_TYPE_NUM_SINT                     0x00000003
#define NVC597_TEXHEAD_1D_B_DATA_TYPE_NUM_UINT                     0x00000004
#define NVC597_TEXHEAD_1D_B_DATA_TYPE_NUM_SNORM_FORCE_FP16         0x00000005
#define NVC597_TEXHEAD_1D_B_DATA_TYPE_NUM_UNORM_FORCE_FP16         0x00000006
#define NVC597_TEXHEAD_1D_B_DATA_TYPE_NUM_FLOAT                    0x00000007
#define NVC597_TEXHEAD_1D_A_DATA_TYPE                              MW(18:16)
#define NVC597_TEXHEAD_1D_A_DATA_TYPE_NUM_SNORM                    0x00000001
#define NVC597_TEXHEAD_1D_A_DATA_TYPE_NUM_UNORM                    0x00000002
#define NVC597_TEXHEAD_1D_A_DATA_TYPE_NUM_SINT                     0x00000003
#define NVC597_TEXHEAD_1D_A_DATA_TYPE_NUM_UINT                     0x00000004
#define NVC597_TEXHEAD_1D_A_DATA_TYPE_NUM_SNORM_FORCE_FP16         0x00000005
#define NVC597_TEXHEAD_1D_A_DATA_TYPE_NUM_UNORM_FORCE_FP16         0x00000006
#define NVC597_TEXHEAD_1D_A_DATA_TYPE_NUM_FLOAT                    0x00000007
#define NVC597_TEXHEAD_1D_X_SOURCE                                 MW(21:19)
#define NVC597_TEXHEAD_1D_X_SOURCE_IN_ZERO                         0x00000000
#define NVC597_TEXHEAD_1D_X_SOURCE_IN_R                            0x00000002
#define NVC597_TEXHEAD_1D_X_SOURCE_IN_G                            0x00000003
#define NVC597_TEXHEAD_1D_X_SOURCE_IN_B                            0x00000004
#define NVC597_TEXHEAD_1D_X_SOURCE_IN_A                            0x00000005
#define NVC597_TEXHEAD_1D_X_SOURCE_IN_ONE_INT                      0x00000006
#define NVC597_TEXHEAD_1D_X_SOURCE_IN_ONE_FLOAT                    0x00000007
#define NVC597_TEXHEAD_1D_Y_SOURCE                                 MW(24:22)
#define NVC597_TEXHEAD_1D_Y_SOURCE_IN_ZERO                         0x00000000
#define NVC597_TEXHEAD_1D_Y_SOURCE_IN_R                            0x00000002
#define NVC597_TEXHEAD_1D_Y_SOURCE_IN_G                            0x00000003
#define NVC597_TEXHEAD_1D_Y_SOURCE_IN_B                            0x00000004
#define NVC597_TEXHEAD_1D_Y_SOURCE_IN_A                            0x00000005
#define NVC597_TEXHEAD_1D_Y_SOURCE_IN_ONE_INT                      0x00000006
#define NVC597_TEXHEAD_1D_Y_SOURCE_IN_ONE_FLOAT                    0x00000007
#define NVC597_TEXHEAD_1D_Z_SOURCE                                 MW(27:25)
#define NVC597_TEXHEAD_1D_Z_SOURCE_IN_ZERO                         0x00000000
#define NVC597_TEXHEAD_1D_Z_SOURCE_IN_R                            0x00000002
#define NVC597_TEXHEAD_1D_Z_SOURCE_IN_G                            0x00000003
#define NVC597_TEXHEAD_1D_Z_SOURCE_IN_B                            0x00000004
#define NVC597_TEXHEAD_1D_Z_SOURCE_IN_A                            0x00000005
#define NVC597_TEXHEAD_1D_Z_SOURCE_IN_ONE_INT                      0x00000006
#define NVC597_TEXHEAD_1D_Z_SOURCE_IN_ONE_FLOAT                    0x00000007
#define NVC597_TEXHEAD_1D_W_SOURCE                                 MW(30:28)
#define NVC597_TEXHEAD_1D_W_SOURCE_IN_ZERO                         0x00000000
#define NVC597_TEXHEAD_1D_W_SOURCE_IN_R                            0x00000002
#define NVC597_TEXHEAD_1D_W_SOURCE_IN_G                            0x00000003
#define NVC597_TEXHEAD_1D_W_SOURCE_IN_B                            0x00000004
#define NVC597_TEXHEAD_1D_W_SOURCE_IN_A                            0x00000005
#define NVC597_TEXHEAD_1D_W_SOURCE_IN_ONE_INT                      0x00000006
#define NVC597_TEXHEAD_1D_W_SOURCE_IN_ONE_FLOAT                    0x00000007
#define NVC597_TEXHEAD_1D_PACK_COMPONENTS                          MW(31:31)
#define NVC597_TEXHEAD_1D_ADDRESS_BITS31TO0                        MW(63:32)
#define NVC597_TEXHEAD_1D_ADDRESS_BITS48TO32                       MW(80:64)
#define NVC597_TEXHEAD_1D_RESERVED_ADDRESS                         MW(84:81)
#define NVC597_TEXHEAD_1D_HEADER_VERSION                           MW(87:85)
#define NVC597_TEXHEAD_1D_HEADER_VERSION_SELECT_ONE_D_BUFFER       0x00000000
#define NVC597_TEXHEAD_1D_HEADER_VERSION_SELECT_PITCH_COLOR_KEY    0x00000001
#define NVC597_TEXHEAD_1D_HEADER_VERSION_SELECT_PITCH              0x00000002
#define NVC597_TEXHEAD_1D_HEADER_VERSION_SELECT_BLOCKLINEAR        0x00000003
#define NVC597_TEXHEAD_1D_HEADER_VERSION_SELECT_BLOCKLINEAR_COLOR_KEY 0x00000004
#define NVC597_TEXHEAD_1D_RESERVED_HEADER_VERSION                  MW(88:88)
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH             MW(92:89)
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_0 0x00000000
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_1 0x00000001
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_2 0x00000002
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_3 0x00000003
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_4 0x00000004
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_5 0x00000005
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_6 0x00000006
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_7 0x00000007
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_8 0x00000008
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_9 0x00000009
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_10 0x0000000a
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_11 0x0000000b
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_12 0x0000000c
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_13 0x0000000d
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_14 0x0000000e
#define NVC597_TEXHEAD_1D_RESOURCE_VIEW_COHERENCY_HASH_HASH_UNALIASED 0x0000000f
#define NVC597_TEXHEAD_1D_RESERVED2A                               MW(95:93)
#define NVC597_TEXHEAD_1D_WIDTH_MINUS_ONE_BITS31TO16               MW(111:96)
#define NVC597_TEXHEAD_1D_RESERVED3X                               MW(127:112)
#define NVC597_TEXHEAD_1D_WIDTH_MINUS_ONE_BITS15TO0                MW(143:128)
#define NVC597_TEXHEAD_1D_RESERVED4X                               MW(149:144)
#define NVC597_TEXHEAD_1D_S_R_G_B_CONVERSION                       MW(150:150)
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE                             MW(154:151)
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_ONE_D                       0x00000000
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_TWO_D                       0x00000001
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_THREE_D                     0x00000002
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_CUBEMAP                     0x00000003
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_ONE_D_ARRAY                 0x00000004
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_TWO_D_ARRAY                 0x00000005
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_ONE_D_BUFFER                0x00000006
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_TWO_D_NO_MIPMAP             0x00000007
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_CUBEMAP_ARRAY               0x00000008
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_HTEX_TWOD                   0x0000000a
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_HTEX_THREE_D                0x0000000b
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_HTEX_TWOD_ARRAY             0x0000000e
#define NVC597_TEXHEAD_1D_TEXTURE_TYPE_TT_BIT_FIELD_SIZE           0x0000000f
#define NVC597_TEXHEAD_1D_SECTOR_PROMOTION                         MW(156:155)
#define NVC597_TEXHEAD_1D_SECTOR_PROMOTION_NO_PROMOTION            0x00000000
#define NVC597_TEXHEAD_1D_SECTOR_PROMOTION_PROMOTE_TO_2_V          0x00000001
#define NVC597_TEXHEAD_1D_SECTOR_PROMOTION_PROMOTE_TO_2_H          0x00000002
#define NVC597_TEXHEAD_1D_SECTOR_PROMOTION_PROMOTE_TO_4            0x00000003
#define NVC597_TEXHEAD_1D_RESERVED4Y                               MW(159:157)
#define NVC597_TEXHEAD_1D_RESERVED5X                               MW(189:160)
#define NVC597_TEXHEAD_1D_RESERVED5A                               MW(190:190)
#define NVC597_TEXHEAD_1D_RESERVED5Y                               MW(191:191)
#define NVC597_TEXHEAD_1D_RESERVED6X                               MW(223:192)
#define NVC597_TEXHEAD_1D_RESERVED7X                               MW(255:224)


/*
** Texture Header State Pitch
 */

#define NVC597_TEXHEAD_PITCH_COMPONENTS                            MW(6:0)
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_INVALID              0x00000000
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_R32_G32_B32_A32      0x00000001
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_R32_G32_B32          0x00000002
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_R16_G16_B16_A16      0x00000003
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_R32_G32              0x00000004
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_R32_B24G8            0x00000005
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_X8B8G8R8             0x00000007
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_A8B8G8R8             0x00000008
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_A2B10G10R10          0x00000009
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_R16_G16              0x0000000c
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_G8R24                0x0000000d
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_G24R8                0x0000000e
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_R32                  0x0000000f
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_A4B4G4R4             0x00000012
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_A5B5G5R1             0x00000013
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_A1B5G5R5             0x00000014
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_B5G6R5               0x00000015
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_B6G5R5               0x00000016
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_G8R8                 0x00000018
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_R16                  0x0000001b
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_Y8_VIDEO             0x0000001c
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_R8                   0x0000001d
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_G4R4                 0x0000001e
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_R1                   0x0000001f
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_E5B9G9R9_SHAREDEXP   0x00000020
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_BF10GF11RF11         0x00000021
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_G8B8G8R8             0x00000022
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_B8G8R8G8             0x00000023
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_DXT1                 0x00000024
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_DXT23                0x00000025
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_DXT45                0x00000026
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_DXN1                 0x00000027
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_DXN2                 0x00000028
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_BC6H_SF16            0x00000010
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_BC6H_UF16            0x00000011
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_BC7U                 0x00000017
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ETC2_RGB             0x00000006
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ETC2_RGB_PTA         0x0000000a
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ETC2_RGBA            0x0000000b
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_EAC                  0x00000019
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_EACX2                0x0000001a
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_Z24S8                0x00000029
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_X8Z24                0x0000002a
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_S8Z24                0x0000002b
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_X4V4Z24__COV4R4V     0x0000002c
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_X4V4Z24__COV8R8V     0x0000002d
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_V8Z24__COV4R12V      0x0000002e
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ZF32                 0x0000002f
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ZF32_X24S8           0x00000030
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_X8Z24_X20V4S8__COV4R4V 0x00000031
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_X8Z24_X20V4S8__COV8R8V 0x00000032
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ZF32_X20V4X8__COV4R4V 0x00000033
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ZF32_X20V4X8__COV8R8V 0x00000034
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ZF32_X20V4S8__COV4R4V 0x00000035
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ZF32_X20V4S8__COV8R8V 0x00000036
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_X8Z24_X16V8S8__COV4R12V 0x00000037
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ZF32_X16V8X8__COV4R12V 0x00000038
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ZF32_X16V8S8__COV4R12V 0x00000039
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_Z16                  0x0000003a
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_V8Z24__COV8R24V      0x0000003b
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_X8Z24_X16V8S8__COV8R24V 0x0000003c
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ZF32_X16V8X8__COV8R24V 0x0000003d
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ZF32_X16V8S8__COV8R24V 0x0000003e
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_4X4          0x00000040
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_5X4          0x00000050
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_5X5          0x00000041
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_6X5          0x00000051
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_6X6          0x00000042
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_8X5          0x00000055
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_8X6          0x00000052
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_8X8          0x00000044
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_10X5         0x00000056
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_10X6         0x00000057
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_10X8         0x00000053
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_10X10        0x00000045
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_12X10        0x00000054
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_ASTC_2D_12X12        0x00000046
#define NVC597_TEXHEAD_PITCH_COMPONENTS_SIZES_CS_BITFIELD_SIZE     0x0000007f
#define NVC597_TEXHEAD_PITCH_R_DATA_TYPE                           MW(9:7)
#define NVC597_TEXHEAD_PITCH_R_DATA_TYPE_NUM_SNORM                 0x00000001
#define NVC597_TEXHEAD_PITCH_R_DATA_TYPE_NUM_UNORM                 0x00000002
#define NVC597_TEXHEAD_PITCH_R_DATA_TYPE_NUM_SINT                  0x00000003
#define NVC597_TEXHEAD_PITCH_R_DATA_TYPE_NUM_UINT                  0x00000004
#define NVC597_TEXHEAD_PITCH_R_DATA_TYPE_NUM_SNORM_FORCE_FP16      0x00000005
#define NVC597_TEXHEAD_PITCH_R_DATA_TYPE_NUM_UNORM_FORCE_FP16      0x00000006
#define NVC597_TEXHEAD_PITCH_R_DATA_TYPE_NUM_FLOAT                 0x00000007
#define NVC597_TEXHEAD_PITCH_G_DATA_TYPE                           MW(12:10)
#define NVC597_TEXHEAD_PITCH_G_DATA_TYPE_NUM_SNORM                 0x00000001
#define NVC597_TEXHEAD_PITCH_G_DATA_TYPE_NUM_UNORM                 0x00000002
#define NVC597_TEXHEAD_PITCH_G_DATA_TYPE_NUM_SINT                  0x00000003
#define NVC597_TEXHEAD_PITCH_G_DATA_TYPE_NUM_UINT                  0x00000004
#define NVC597_TEXHEAD_PITCH_G_DATA_TYPE_NUM_SNORM_FORCE_FP16      0x00000005
#define NVC597_TEXHEAD_PITCH_G_DATA_TYPE_NUM_UNORM_FORCE_FP16      0x00000006
#define NVC597_TEXHEAD_PITCH_G_DATA_TYPE_NUM_FLOAT                 0x00000007
#define NVC597_TEXHEAD_PITCH_B_DATA_TYPE                           MW(15:13)
#define NVC597_TEXHEAD_PITCH_B_DATA_TYPE_NUM_SNORM                 0x00000001
#define NVC597_TEXHEAD_PITCH_B_DATA_TYPE_NUM_UNORM                 0x00000002
#define NVC597_TEXHEAD_PITCH_B_DATA_TYPE_NUM_SINT                  0x00000003
#define NVC597_TEXHEAD_PITCH_B_DATA_TYPE_NUM_UINT                  0x00000004
#define NVC597_TEXHEAD_PITCH_B_DATA_TYPE_NUM_SNORM_FORCE_FP16      0x00000005
#define NVC597_TEXHEAD_PITCH_B_DATA_TYPE_NUM_UNORM_FORCE_FP16      0x00000006
#define NVC597_TEXHEAD_PITCH_B_DATA_TYPE_NUM_FLOAT                 0x00000007
#define NVC597_TEXHEAD_PITCH_A_DATA_TYPE                           MW(18:16)
#define NVC597_TEXHEAD_PITCH_A_DATA_TYPE_NUM_SNORM                 0x00000001
#define NVC597_TEXHEAD_PITCH_A_DATA_TYPE_NUM_UNORM                 0x00000002
#define NVC597_TEXHEAD_PITCH_A_DATA_TYPE_NUM_SINT                  0x00000003
#define NVC597_TEXHEAD_PITCH_A_DATA_TYPE_NUM_UINT                  0x00000004
#define NVC597_TEXHEAD_PITCH_A_DATA_TYPE_NUM_SNORM_FORCE_FP16      0x00000005
#define NVC597_TEXHEAD_PITCH_A_DATA_TYPE_NUM_UNORM_FORCE_FP16      0x00000006
#define NVC597_TEXHEAD_PITCH_A_DATA_TYPE_NUM_FLOAT                 0x00000007
#define NVC597_TEXHEAD_PITCH_X_SOURCE                              MW(21:19)
#define NVC597_TEXHEAD_PITCH_X_SOURCE_IN_ZERO                      0x00000000
#define NVC597_TEXHEAD_PITCH_X_SOURCE_IN_R                         0x00000002
#define NVC597_TEXHEAD_PITCH_X_SOURCE_IN_G                         0x00000003
#define NVC597_TEXHEAD_PITCH_X_SOURCE_IN_B                         0x00000004
#define NVC597_TEXHEAD_PITCH_X_SOURCE_IN_A                         0x00000005
#define NVC597_TEXHEAD_PITCH_X_SOURCE_IN_ONE_INT                   0x00000006
#define NVC597_TEXHEAD_PITCH_X_SOURCE_IN_ONE_FLOAT                 0x00000007
#define NVC597_TEXHEAD_PITCH_Y_SOURCE                              MW(24:22)
#define NVC597_TEXHEAD_PITCH_Y_SOURCE_IN_ZERO                      0x00000000
#define NVC597_TEXHEAD_PITCH_Y_SOURCE_IN_R                         0x00000002
#define NVC597_TEXHEAD_PITCH_Y_SOURCE_IN_G                         0x00000003
#define NVC597_TEXHEAD_PITCH_Y_SOURCE_IN_B                         0x00000004
#define NVC597_TEXHEAD_PITCH_Y_SOURCE_IN_A                         0x00000005
#define NVC597_TEXHEAD_PITCH_Y_SOURCE_IN_ONE_INT                   0x00000006
#define NVC597_TEXHEAD_PITCH_Y_SOURCE_IN_ONE_FLOAT                 0x00000007
#define NVC597_TEXHEAD_PITCH_Z_SOURCE                              MW(27:25)
#define NVC597_TEXHEAD_PITCH_Z_SOURCE_IN_ZERO                      0x00000000
#define NVC597_TEXHEAD_PITCH_Z_SOURCE_IN_R                         0x00000002
#define NVC597_TEXHEAD_PITCH_Z_SOURCE_IN_G                         0x00000003
#define NVC597_TEXHEAD_PITCH_Z_SOURCE_IN_B                         0x00000004
#define NVC597_TEXHEAD_PITCH_Z_SOURCE_IN_A                         0x00000005
#define NVC597_TEXHEAD_PITCH_Z_SOURCE_IN_ONE_INT                   0x00000006
#define NVC597_TEXHEAD_PITCH_Z_SOURCE_IN_ONE_FLOAT                 0x00000007
#define NVC597_TEXHEAD_PITCH_W_SOURCE                              MW(30:28)
#define NVC597_TEXHEAD_PITCH_W_SOURCE_IN_ZERO                      0x00000000
#define NVC597_TEXHEAD_PITCH_W_SOURCE_IN_R                         0x00000002
#define NVC597_TEXHEAD_PITCH_W_SOURCE_IN_G                         0x00000003
#define NVC597_TEXHEAD_PITCH_W_SOURCE_IN_B                         0x00000004
#define NVC597_TEXHEAD_PITCH_W_SOURCE_IN_A                         0x00000005
#define NVC597_TEXHEAD_PITCH_W_SOURCE_IN_ONE_INT                   0x00000006
#define NVC597_TEXHEAD_PITCH_W_SOURCE_IN_ONE_FLOAT                 0x00000007
#define NVC597_TEXHEAD_PITCH_PACK_COMPONENTS                       MW(31:31)
#define NVC597_TEXHEAD_PITCH_RESERVED1A                            MW(36:32)
#define NVC597_TEXHEAD_PITCH_ADDRESS_BITS31TO5                     MW(63:37)
#define NVC597_TEXHEAD_PITCH_ADDRESS_BITS48TO32                    MW(80:64)
#define NVC597_TEXHEAD_PITCH_RESERVED_ADDRESS                      MW(84:81)
#define NVC597_TEXHEAD_PITCH_HEADER_VERSION                        MW(87:85)
#define NVC597_TEXHEAD_PITCH_HEADER_VERSION_SELECT_ONE_D_BUFFER    0x00000000
#define NVC597_TEXHEAD_PITCH_HEADER_VERSION_SELECT_PITCH_COLOR_KEY 0x00000001
#define NVC597_TEXHEAD_PITCH_HEADER_VERSION_SELECT_PITCH           0x00000002
#define NVC597_TEXHEAD_PITCH_HEADER_VERSION_SELECT_BLOCKLINEAR     0x00000003
#define NVC597_TEXHEAD_PITCH_HEADER_VERSION_SELECT_BLOCKLINEAR_COLOR_KEY 0x00000004
#define NVC597_TEXHEAD_PITCH_RESERVED_HEADER_VERSION               MW(88:88)
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH          MW(92:89)
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_0 0x00000000
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_1 0x00000001
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_2 0x00000002
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_3 0x00000003
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_4 0x00000004
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_5 0x00000005
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_6 0x00000006
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_7 0x00000007
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_8 0x00000008
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_9 0x00000009
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_10 0x0000000a
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_11 0x0000000b
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_12 0x0000000c
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_13 0x0000000d
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_14 0x0000000e
#define NVC597_TEXHEAD_PITCH_RESOURCE_VIEW_COHERENCY_HASH_HASH_UNALIASED 0x0000000f
#define NVC597_TEXHEAD_PITCH_RESERVED2A                            MW(95:93)
#define NVC597_TEXHEAD_PITCH_PITCH_BITS20TO5                       MW(111:96)
#define NVC597_TEXHEAD_PITCH_LOD_ANISO_QUALITY2                    MW(112:112)
#define NVC597_TEXHEAD_PITCH_LOD_ANISO_QUALITY                     MW(113:113)
#define NVC597_TEXHEAD_PITCH_LOD_ANISO_QUALITY_LOD_QUALITY_LOW     0x00000000
#define NVC597_TEXHEAD_PITCH_LOD_ANISO_QUALITY_LOD_QUALITY_HIGH    0x00000001
#define NVC597_TEXHEAD_PITCH_LOD_ISO_QUALITY                       MW(114:114)
#define NVC597_TEXHEAD_PITCH_LOD_ISO_QUALITY_LOD_QUALITY_LOW       0x00000000
#define NVC597_TEXHEAD_PITCH_LOD_ISO_QUALITY_LOD_QUALITY_HIGH      0x00000001
#define NVC597_TEXHEAD_PITCH_ANISO_COARSE_SPREAD_MODIFIER          MW(116:115)
#define NVC597_TEXHEAD_PITCH_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_NONE 0x00000000
#define NVC597_TEXHEAD_PITCH_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_ONE 0x00000001
#define NVC597_TEXHEAD_PITCH_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_TWO 0x00000002
#define NVC597_TEXHEAD_PITCH_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_SQRT 0x00000003
#define NVC597_TEXHEAD_PITCH_ANISO_SPREAD_SCALE                    MW(121:117)
#define NVC597_TEXHEAD_PITCH_USE_HEADER_OPT_CONTROL                MW(122:122)
#define NVC597_TEXHEAD_PITCH_DEPTH_TEXTURE                         MW(123:123)
#define NVC597_TEXHEAD_PITCH_MAX_MIP_LEVEL                         MW(127:124)
#define NVC597_TEXHEAD_PITCH_WIDTH_MINUS_ONE                       MW(144:128)
#define NVC597_TEXHEAD_PITCH_PITCH_BIT21                           MW(145:145)
#define NVC597_TEXHEAD_PITCH_HEIGHT_MINUS_ONE_BIT16                MW(146:146)
#define NVC597_TEXHEAD_PITCH_ANISO_SPREAD_MAX_LOG2                 MW(149:147)
#define NVC597_TEXHEAD_PITCH_S_R_G_B_CONVERSION                    MW(150:150)
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE                          MW(154:151)
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_ONE_D                    0x00000000
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_TWO_D                    0x00000001
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_THREE_D                  0x00000002
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_CUBEMAP                  0x00000003
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_ONE_D_ARRAY              0x00000004
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_TWO_D_ARRAY              0x00000005
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_ONE_D_BUFFER             0x00000006
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_TWO_D_NO_MIPMAP          0x00000007
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_CUBEMAP_ARRAY            0x00000008
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_HTEX_TWOD                0x0000000a
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_HTEX_THREE_D             0x0000000b
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_HTEX_TWOD_ARRAY          0x0000000e
#define NVC597_TEXHEAD_PITCH_TEXTURE_TYPE_TT_BIT_FIELD_SIZE        0x0000000f
#define NVC597_TEXHEAD_PITCH_SECTOR_PROMOTION                      MW(156:155)
#define NVC597_TEXHEAD_PITCH_SECTOR_PROMOTION_NO_PROMOTION         0x00000000
#define NVC597_TEXHEAD_PITCH_SECTOR_PROMOTION_PROMOTE_TO_2_V       0x00000001
#define NVC597_TEXHEAD_PITCH_SECTOR_PROMOTION_PROMOTE_TO_2_H       0x00000002
#define NVC597_TEXHEAD_PITCH_SECTOR_PROMOTION_PROMOTE_TO_4         0x00000003
#define NVC597_TEXHEAD_PITCH_BORDER_SIZE                           MW(159:157)
#define NVC597_TEXHEAD_PITCH_BORDER_SIZE_BORDER_SIZE_ONE           0x00000000
#define NVC597_TEXHEAD_PITCH_BORDER_SIZE_BORDER_SIZE_TWO           0x00000001
#define NVC597_TEXHEAD_PITCH_BORDER_SIZE_BORDER_SIZE_FOUR          0x00000002
#define NVC597_TEXHEAD_PITCH_BORDER_SIZE_BORDER_SIZE_EIGHT         0x00000003
#define NVC597_TEXHEAD_PITCH_BORDER_SIZE_BORDER_SAMPLER_COLOR      0x00000007
#define NVC597_TEXHEAD_PITCH_HEIGHT_MINUS_ONE                      MW(175:160)
#define NVC597_TEXHEAD_PITCH_DEPTH_MINUS_ONE                       MW(189:176)
#define NVC597_TEXHEAD_PITCH_RESERVED5A                            MW(190:190)
#define NVC597_TEXHEAD_PITCH_NORMALIZED_COORDS                     MW(191:191)
#define NVC597_TEXHEAD_PITCH_RESERVED6Y                            MW(192:192)
#define NVC597_TEXHEAD_PITCH_TRILIN_OPT                            MW(197:193)
#define NVC597_TEXHEAD_PITCH_MIP_LOD_BIAS                          MW(210:198)
#define NVC597_TEXHEAD_PITCH_ANISO_BIAS                            MW(214:211)
#define NVC597_TEXHEAD_PITCH_ANISO_FINE_SPREAD_FUNC                MW(216:215)
#define NVC597_TEXHEAD_PITCH_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_HALF 0x00000000
#define NVC597_TEXHEAD_PITCH_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_ONE 0x00000001
#define NVC597_TEXHEAD_PITCH_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_TWO 0x00000002
#define NVC597_TEXHEAD_PITCH_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_MAX 0x00000003
#define NVC597_TEXHEAD_PITCH_ANISO_COARSE_SPREAD_FUNC              MW(218:217)
#define NVC597_TEXHEAD_PITCH_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_HALF 0x00000000
#define NVC597_TEXHEAD_PITCH_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_ONE 0x00000001
#define NVC597_TEXHEAD_PITCH_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_TWO 0x00000002
#define NVC597_TEXHEAD_PITCH_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_MAX 0x00000003
#define NVC597_TEXHEAD_PITCH_MAX_ANISOTROPY                        MW(221:219)
#define NVC597_TEXHEAD_PITCH_MAX_ANISOTROPY_ANISO_1_TO_1           0x00000000
#define NVC597_TEXHEAD_PITCH_MAX_ANISOTROPY_ANISO_2_TO_1           0x00000001
#define NVC597_TEXHEAD_PITCH_MAX_ANISOTROPY_ANISO_4_TO_1           0x00000002
#define NVC597_TEXHEAD_PITCH_MAX_ANISOTROPY_ANISO_6_TO_1           0x00000003
#define NVC597_TEXHEAD_PITCH_MAX_ANISOTROPY_ANISO_8_TO_1           0x00000004
#define NVC597_TEXHEAD_PITCH_MAX_ANISOTROPY_ANISO_10_TO_1          0x00000005
#define NVC597_TEXHEAD_PITCH_MAX_ANISOTROPY_ANISO_12_TO_1          0x00000006
#define NVC597_TEXHEAD_PITCH_MAX_ANISOTROPY_ANISO_16_TO_1          0x00000007
#define NVC597_TEXHEAD_PITCH_ANISO_FINE_SPREAD_MODIFIER            MW(223:222)
#define NVC597_TEXHEAD_PITCH_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_NONE 0x00000000
#define NVC597_TEXHEAD_PITCH_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_ONE 0x00000001
#define NVC597_TEXHEAD_PITCH_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_TWO 0x00000002
#define NVC597_TEXHEAD_PITCH_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_SQRT 0x00000003
#define NVC597_TEXHEAD_PITCH_RES_VIEW_MIN_MIP_LEVEL                MW(227:224)
#define NVC597_TEXHEAD_PITCH_RES_VIEW_MAX_MIP_LEVEL                MW(231:228)
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT                    MW(235:232)
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_1X1           0x00000000
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_2X1           0x00000001
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_2X2           0x00000002
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_4X2           0x00000003
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_4X2_D3D       0x00000004
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_2X1_D3D       0x00000005
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_4X4           0x00000006
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_2X2_VC_4      0x00000008
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_2X2_VC_12     0x00000009
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_4X2_VC_8      0x0000000a
#define NVC597_TEXHEAD_PITCH_MULTI_SAMPLE_COUNT_MODE_4X2_VC_24     0x0000000b
#define NVC597_TEXHEAD_PITCH_MIN_LOD_CLAMP                         MW(247:236)
#define NVC597_TEXHEAD_PITCH_RESERVED7Y                            MW(255:248)


/*
** Texture Header State Pitch Color Key
 */

#define NVC597_TEXHEAD_PITCHCK_COMPONENTS                          MW(6:0)
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_INVALID            0x00000000
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_R32_G32_B32_A32    0x00000001
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_R32_G32_B32        0x00000002
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_R16_G16_B16_A16    0x00000003
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_R32_G32            0x00000004
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_R32_B24G8          0x00000005
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_X8B8G8R8           0x00000007
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_A8B8G8R8           0x00000008
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_A2B10G10R10        0x00000009
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_R16_G16            0x0000000c
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_G8R24              0x0000000d
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_G24R8              0x0000000e
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_R32                0x0000000f
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_A4B4G4R4           0x00000012
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_A5B5G5R1           0x00000013
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_A1B5G5R5           0x00000014
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_B5G6R5             0x00000015
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_B6G5R5             0x00000016
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_G8R8               0x00000018
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_R16                0x0000001b
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_Y8_VIDEO           0x0000001c
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_R8                 0x0000001d
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_G4R4               0x0000001e
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_R1                 0x0000001f
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_E5B9G9R9_SHAREDEXP 0x00000020
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_BF10GF11RF11       0x00000021
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_G8B8G8R8           0x00000022
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_B8G8R8G8           0x00000023
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_DXT1               0x00000024
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_DXT23              0x00000025
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_DXT45              0x00000026
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_DXN1               0x00000027
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_DXN2               0x00000028
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_BC6H_SF16          0x00000010
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_BC6H_UF16          0x00000011
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_BC7U               0x00000017
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ETC2_RGB           0x00000006
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ETC2_RGB_PTA       0x0000000a
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ETC2_RGBA          0x0000000b
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_EAC                0x00000019
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_EACX2              0x0000001a
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_Z24S8              0x00000029
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_X8Z24              0x0000002a
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_S8Z24              0x0000002b
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_X4V4Z24__COV4R4V   0x0000002c
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_X4V4Z24__COV8R8V   0x0000002d
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_V8Z24__COV4R12V    0x0000002e
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ZF32               0x0000002f
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ZF32_X24S8         0x00000030
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_X8Z24_X20V4S8__COV4R4V 0x00000031
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_X8Z24_X20V4S8__COV8R8V 0x00000032
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ZF32_X20V4X8__COV4R4V 0x00000033
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ZF32_X20V4X8__COV8R8V 0x00000034
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ZF32_X20V4S8__COV4R4V 0x00000035
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ZF32_X20V4S8__COV8R8V 0x00000036
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_X8Z24_X16V8S8__COV4R12V 0x00000037
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ZF32_X16V8X8__COV4R12V 0x00000038
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ZF32_X16V8S8__COV4R12V 0x00000039
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_Z16                0x0000003a
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_V8Z24__COV8R24V    0x0000003b
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_X8Z24_X16V8S8__COV8R24V 0x0000003c
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ZF32_X16V8X8__COV8R24V 0x0000003d
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ZF32_X16V8S8__COV8R24V 0x0000003e
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_4X4        0x00000040
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_5X4        0x00000050
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_5X5        0x00000041
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_6X5        0x00000051
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_6X6        0x00000042
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_8X5        0x00000055
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_8X6        0x00000052
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_8X8        0x00000044
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_10X5       0x00000056
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_10X6       0x00000057
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_10X8       0x00000053
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_10X10      0x00000045
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_12X10      0x00000054
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_ASTC_2D_12X12      0x00000046
#define NVC597_TEXHEAD_PITCHCK_COMPONENTS_SIZES_CS_BITFIELD_SIZE   0x0000007f
#define NVC597_TEXHEAD_PITCHCK_R_DATA_TYPE                         MW(9:7)
#define NVC597_TEXHEAD_PITCHCK_R_DATA_TYPE_NUM_SNORM               0x00000001
#define NVC597_TEXHEAD_PITCHCK_R_DATA_TYPE_NUM_UNORM               0x00000002
#define NVC597_TEXHEAD_PITCHCK_R_DATA_TYPE_NUM_SINT                0x00000003
#define NVC597_TEXHEAD_PITCHCK_R_DATA_TYPE_NUM_UINT                0x00000004
#define NVC597_TEXHEAD_PITCHCK_R_DATA_TYPE_NUM_SNORM_FORCE_FP16    0x00000005
#define NVC597_TEXHEAD_PITCHCK_R_DATA_TYPE_NUM_UNORM_FORCE_FP16    0x00000006
#define NVC597_TEXHEAD_PITCHCK_R_DATA_TYPE_NUM_FLOAT               0x00000007
#define NVC597_TEXHEAD_PITCHCK_G_DATA_TYPE                         MW(12:10)
#define NVC597_TEXHEAD_PITCHCK_G_DATA_TYPE_NUM_SNORM               0x00000001
#define NVC597_TEXHEAD_PITCHCK_G_DATA_TYPE_NUM_UNORM               0x00000002
#define NVC597_TEXHEAD_PITCHCK_G_DATA_TYPE_NUM_SINT                0x00000003
#define NVC597_TEXHEAD_PITCHCK_G_DATA_TYPE_NUM_UINT                0x00000004
#define NVC597_TEXHEAD_PITCHCK_G_DATA_TYPE_NUM_SNORM_FORCE_FP16    0x00000005
#define NVC597_TEXHEAD_PITCHCK_G_DATA_TYPE_NUM_UNORM_FORCE_FP16    0x00000006
#define NVC597_TEXHEAD_PITCHCK_G_DATA_TYPE_NUM_FLOAT               0x00000007
#define NVC597_TEXHEAD_PITCHCK_B_DATA_TYPE                         MW(15:13)
#define NVC597_TEXHEAD_PITCHCK_B_DATA_TYPE_NUM_SNORM               0x00000001
#define NVC597_TEXHEAD_PITCHCK_B_DATA_TYPE_NUM_UNORM               0x00000002
#define NVC597_TEXHEAD_PITCHCK_B_DATA_TYPE_NUM_SINT                0x00000003
#define NVC597_TEXHEAD_PITCHCK_B_DATA_TYPE_NUM_UINT                0x00000004
#define NVC597_TEXHEAD_PITCHCK_B_DATA_TYPE_NUM_SNORM_FORCE_FP16    0x00000005
#define NVC597_TEXHEAD_PITCHCK_B_DATA_TYPE_NUM_UNORM_FORCE_FP16    0x00000006
#define NVC597_TEXHEAD_PITCHCK_B_DATA_TYPE_NUM_FLOAT               0x00000007
#define NVC597_TEXHEAD_PITCHCK_A_DATA_TYPE                         MW(18:16)
#define NVC597_TEXHEAD_PITCHCK_A_DATA_TYPE_NUM_SNORM               0x00000001
#define NVC597_TEXHEAD_PITCHCK_A_DATA_TYPE_NUM_UNORM               0x00000002
#define NVC597_TEXHEAD_PITCHCK_A_DATA_TYPE_NUM_SINT                0x00000003
#define NVC597_TEXHEAD_PITCHCK_A_DATA_TYPE_NUM_UINT                0x00000004
#define NVC597_TEXHEAD_PITCHCK_A_DATA_TYPE_NUM_SNORM_FORCE_FP16    0x00000005
#define NVC597_TEXHEAD_PITCHCK_A_DATA_TYPE_NUM_UNORM_FORCE_FP16    0x00000006
#define NVC597_TEXHEAD_PITCHCK_A_DATA_TYPE_NUM_FLOAT               0x00000007
#define NVC597_TEXHEAD_PITCHCK_X_SOURCE                            MW(21:19)
#define NVC597_TEXHEAD_PITCHCK_X_SOURCE_IN_ZERO                    0x00000000
#define NVC597_TEXHEAD_PITCHCK_X_SOURCE_IN_R                       0x00000002
#define NVC597_TEXHEAD_PITCHCK_X_SOURCE_IN_G                       0x00000003
#define NVC597_TEXHEAD_PITCHCK_X_SOURCE_IN_B                       0x00000004
#define NVC597_TEXHEAD_PITCHCK_X_SOURCE_IN_A                       0x00000005
#define NVC597_TEXHEAD_PITCHCK_X_SOURCE_IN_ONE_INT                 0x00000006
#define NVC597_TEXHEAD_PITCHCK_X_SOURCE_IN_ONE_FLOAT               0x00000007
#define NVC597_TEXHEAD_PITCHCK_Y_SOURCE                            MW(24:22)
#define NVC597_TEXHEAD_PITCHCK_Y_SOURCE_IN_ZERO                    0x00000000
#define NVC597_TEXHEAD_PITCHCK_Y_SOURCE_IN_R                       0x00000002
#define NVC597_TEXHEAD_PITCHCK_Y_SOURCE_IN_G                       0x00000003
#define NVC597_TEXHEAD_PITCHCK_Y_SOURCE_IN_B                       0x00000004
#define NVC597_TEXHEAD_PITCHCK_Y_SOURCE_IN_A                       0x00000005
#define NVC597_TEXHEAD_PITCHCK_Y_SOURCE_IN_ONE_INT                 0x00000006
#define NVC597_TEXHEAD_PITCHCK_Y_SOURCE_IN_ONE_FLOAT               0x00000007
#define NVC597_TEXHEAD_PITCHCK_Z_SOURCE                            MW(27:25)
#define NVC597_TEXHEAD_PITCHCK_Z_SOURCE_IN_ZERO                    0x00000000
#define NVC597_TEXHEAD_PITCHCK_Z_SOURCE_IN_R                       0x00000002
#define NVC597_TEXHEAD_PITCHCK_Z_SOURCE_IN_G                       0x00000003
#define NVC597_TEXHEAD_PITCHCK_Z_SOURCE_IN_B                       0x00000004
#define NVC597_TEXHEAD_PITCHCK_Z_SOURCE_IN_A                       0x00000005
#define NVC597_TEXHEAD_PITCHCK_Z_SOURCE_IN_ONE_INT                 0x00000006
#define NVC597_TEXHEAD_PITCHCK_Z_SOURCE_IN_ONE_FLOAT               0x00000007
#define NVC597_TEXHEAD_PITCHCK_W_SOURCE                            MW(30:28)
#define NVC597_TEXHEAD_PITCHCK_W_SOURCE_IN_ZERO                    0x00000000
#define NVC597_TEXHEAD_PITCHCK_W_SOURCE_IN_R                       0x00000002
#define NVC597_TEXHEAD_PITCHCK_W_SOURCE_IN_G                       0x00000003
#define NVC597_TEXHEAD_PITCHCK_W_SOURCE_IN_B                       0x00000004
#define NVC597_TEXHEAD_PITCHCK_W_SOURCE_IN_A                       0x00000005
#define NVC597_TEXHEAD_PITCHCK_W_SOURCE_IN_ONE_INT                 0x00000006
#define NVC597_TEXHEAD_PITCHCK_W_SOURCE_IN_ONE_FLOAT               0x00000007
#define NVC597_TEXHEAD_PITCHCK_PACK_COMPONENTS                     MW(31:31)
#define NVC597_TEXHEAD_PITCHCK_RESERVED1A                          MW(36:32)
#define NVC597_TEXHEAD_PITCHCK_ADDRESS_BITS31TO5                   MW(63:37)
#define NVC597_TEXHEAD_PITCHCK_ADDRESS_BITS48TO32                  MW(80:64)
#define NVC597_TEXHEAD_PITCHCK_RESERVED_ADDRESS                    MW(84:81)
#define NVC597_TEXHEAD_PITCHCK_HEADER_VERSION                      MW(87:85)
#define NVC597_TEXHEAD_PITCHCK_HEADER_VERSION_SELECT_ONE_D_BUFFER  0x00000000
#define NVC597_TEXHEAD_PITCHCK_HEADER_VERSION_SELECT_PITCH_COLOR_KEY 0x00000001
#define NVC597_TEXHEAD_PITCHCK_HEADER_VERSION_SELECT_PITCH         0x00000002
#define NVC597_TEXHEAD_PITCHCK_HEADER_VERSION_SELECT_BLOCKLINEAR   0x00000003
#define NVC597_TEXHEAD_PITCHCK_HEADER_VERSION_SELECT_BLOCKLINEAR_COLOR_KEY 0x00000004
#define NVC597_TEXHEAD_PITCHCK_RESERVED_HEADER_VERSION             MW(88:88)
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH        MW(92:89)
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_0 0x00000000
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_1 0x00000001
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_2 0x00000002
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_3 0x00000003
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_4 0x00000004
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_5 0x00000005
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_6 0x00000006
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_7 0x00000007
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_8 0x00000008
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_9 0x00000009
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_10 0x0000000a
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_11 0x0000000b
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_12 0x0000000c
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_13 0x0000000d
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_ALIASED_14 0x0000000e
#define NVC597_TEXHEAD_PITCHCK_RESOURCE_VIEW_COHERENCY_HASH_HASH_UNALIASED 0x0000000f
#define NVC597_TEXHEAD_PITCHCK_RESERVED2A                          MW(95:93)
#define NVC597_TEXHEAD_PITCHCK_PITCH_BITS20TO5                     MW(111:96)
#define NVC597_TEXHEAD_PITCHCK_LOD_ANISO_QUALITY2                  MW(112:112)
#define NVC597_TEXHEAD_PITCHCK_LOD_ANISO_QUALITY                   MW(113:113)
#define NVC597_TEXHEAD_PITCHCK_LOD_ANISO_QUALITY_LOD_QUALITY_LOW   0x00000000
#define NVC597_TEXHEAD_PITCHCK_LOD_ANISO_QUALITY_LOD_QUALITY_HIGH  0x00000001
#define NVC597_TEXHEAD_PITCHCK_LOD_ISO_QUALITY                     MW(114:114)
#define NVC597_TEXHEAD_PITCHCK_LOD_ISO_QUALITY_LOD_QUALITY_LOW     0x00000000
#define NVC597_TEXHEAD_PITCHCK_LOD_ISO_QUALITY_LOD_QUALITY_HIGH    0x00000001
#define NVC597_TEXHEAD_PITCHCK_ANISO_COARSE_SPREAD_MODIFIER        MW(116:115)
#define NVC597_TEXHEAD_PITCHCK_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_NONE 0x00000000
#define NVC597_TEXHEAD_PITCHCK_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_ONE 0x00000001
#define NVC597_TEXHEAD_PITCHCK_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_TWO 0x00000002
#define NVC597_TEXHEAD_PITCHCK_ANISO_COARSE_SPREAD_MODIFIER_SPREAD_MODIFIER_SQRT 0x00000003
#define NVC597_TEXHEAD_PITCHCK_ANISO_SPREAD_SCALE                  MW(121:117)
#define NVC597_TEXHEAD_PITCHCK_USE_HEADER_OPT_CONTROL              MW(122:122)
#define NVC597_TEXHEAD_PITCHCK_DEPTH_TEXTURE                       MW(123:123)
#define NVC597_TEXHEAD_PITCHCK_MAX_MIP_LEVEL                       MW(127:124)
#define NVC597_TEXHEAD_PITCHCK_WIDTH_MINUS_ONE                     MW(144:128)
#define NVC597_TEXHEAD_PITCHCK_PITCH_BIT21                         MW(145:145)
#define NVC597_TEXHEAD_PITCHCK_HEIGHT_MINUS_ONE_BIT16              MW(146:146)
#define NVC597_TEXHEAD_PITCHCK_ANISO_SPREAD_MAX_LOG2               MW(149:147)
#define NVC597_TEXHEAD_PITCHCK_S_R_G_B_CONVERSION                  MW(150:150)
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE                        MW(154:151)
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_ONE_D                  0x00000000
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_TWO_D                  0x00000001
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_THREE_D                0x00000002
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_CUBEMAP                0x00000003
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_ONE_D_ARRAY            0x00000004
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_TWO_D_ARRAY            0x00000005
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_ONE_D_BUFFER           0x00000006
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_TWO_D_NO_MIPMAP        0x00000007
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_CUBEMAP_ARRAY          0x00000008
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_HTEX_TWOD              0x0000000a
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_HTEX_THREE_D           0x0000000b
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_HTEX_TWOD_ARRAY        0x0000000e
#define NVC597_TEXHEAD_PITCHCK_TEXTURE_TYPE_TT_BIT_FIELD_SIZE      0x0000000f
#define NVC597_TEXHEAD_PITCHCK_SECTOR_PROMOTION                    MW(156:155)
#define NVC597_TEXHEAD_PITCHCK_SECTOR_PROMOTION_NO_PROMOTION       0x00000000
#define NVC597_TEXHEAD_PITCHCK_SECTOR_PROMOTION_PROMOTE_TO_2_V     0x00000001
#define NVC597_TEXHEAD_PITCHCK_SECTOR_PROMOTION_PROMOTE_TO_2_H     0x00000002
#define NVC597_TEXHEAD_PITCHCK_SECTOR_PROMOTION_PROMOTE_TO_4       0x00000003
#define NVC597_TEXHEAD_PITCHCK_BORDER_SIZE                         MW(159:157)
#define NVC597_TEXHEAD_PITCHCK_BORDER_SIZE_BORDER_SIZE_ONE         0x00000000
#define NVC597_TEXHEAD_PITCHCK_BORDER_SIZE_BORDER_SIZE_TWO         0x00000001
#define NVC597_TEXHEAD_PITCHCK_BORDER_SIZE_BORDER_SIZE_FOUR        0x00000002
#define NVC597_TEXHEAD_PITCHCK_BORDER_SIZE_BORDER_SIZE_EIGHT       0x00000003
#define NVC597_TEXHEAD_PITCHCK_BORDER_SIZE_BORDER_SAMPLER_COLOR    0x00000007
#define NVC597_TEXHEAD_PITCHCK_HEIGHT_MINUS_ONE                    MW(175:160)
#define NVC597_TEXHEAD_PITCHCK_DEPTH_MINUS_ONE                     MW(189:176)
#define NVC597_TEXHEAD_PITCHCK_RESERVED5A                          MW(190:190)
#define NVC597_TEXHEAD_PITCHCK_NORMALIZED_COORDS                   MW(191:191)
#define NVC597_TEXHEAD_PITCHCK_COLOR_KEY_OP                        MW(192:192)
#define NVC597_TEXHEAD_PITCHCK_TRILIN_OPT                          MW(197:193)
#define NVC597_TEXHEAD_PITCHCK_MIP_LOD_BIAS                        MW(210:198)
#define NVC597_TEXHEAD_PITCHCK_ANISO_BIAS                          MW(214:211)
#define NVC597_TEXHEAD_PITCHCK_ANISO_FINE_SPREAD_FUNC              MW(216:215)
#define NVC597_TEXHEAD_PITCHCK_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_HALF 0x00000000
#define NVC597_TEXHEAD_PITCHCK_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_ONE 0x00000001
#define NVC597_TEXHEAD_PITCHCK_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_TWO 0x00000002
#define NVC597_TEXHEAD_PITCHCK_ANISO_FINE_SPREAD_FUNC_SPREAD_FUNC_MAX 0x00000003
#define NVC597_TEXHEAD_PITCHCK_ANISO_COARSE_SPREAD_FUNC            MW(218:217)
#define NVC597_TEXHEAD_PITCHCK_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_HALF 0x00000000
#define NVC597_TEXHEAD_PITCHCK_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_ONE 0x00000001
#define NVC597_TEXHEAD_PITCHCK_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_TWO 0x00000002
#define NVC597_TEXHEAD_PITCHCK_ANISO_COARSE_SPREAD_FUNC_SPREAD_FUNC_MAX 0x00000003
#define NVC597_TEXHEAD_PITCHCK_MAX_ANISOTROPY                      MW(221:219)
#define NVC597_TEXHEAD_PITCHCK_MAX_ANISOTROPY_ANISO_1_TO_1         0x00000000
#define NVC597_TEXHEAD_PITCHCK_MAX_ANISOTROPY_ANISO_2_TO_1         0x00000001
#define NVC597_TEXHEAD_PITCHCK_MAX_ANISOTROPY_ANISO_4_TO_1         0x00000002
#define NVC597_TEXHEAD_PITCHCK_MAX_ANISOTROPY_ANISO_6_TO_1         0x00000003
#define NVC597_TEXHEAD_PITCHCK_MAX_ANISOTROPY_ANISO_8_TO_1         0x00000004
#define NVC597_TEXHEAD_PITCHCK_MAX_ANISOTROPY_ANISO_10_TO_1        0x00000005
#define NVC597_TEXHEAD_PITCHCK_MAX_ANISOTROPY_ANISO_12_TO_1        0x00000006
#define NVC597_TEXHEAD_PITCHCK_MAX_ANISOTROPY_ANISO_16_TO_1        0x00000007
#define NVC597_TEXHEAD_PITCHCK_ANISO_FINE_SPREAD_MODIFIER          MW(223:222)
#define NVC597_TEXHEAD_PITCHCK_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_NONE 0x00000000
#define NVC597_TEXHEAD_PITCHCK_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_ONE 0x00000001
#define NVC597_TEXHEAD_PITCHCK_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_CONST_TWO 0x00000002
#define NVC597_TEXHEAD_PITCHCK_ANISO_FINE_SPREAD_MODIFIER_SPREAD_MODIFIER_SQRT 0x00000003
#define NVC597_TEXHEAD_PITCHCK_COLOR_KEY_VALUE                     MW(255:224)


/*
** Texture Sampler State
 */

#define NVC597_TEXSAMP0_ADDRESS_U                                  2:0
#define NVC597_TEXSAMP0_ADDRESS_U_WRAP                             0x00000000
#define NVC597_TEXSAMP0_ADDRESS_U_MIRROR                           0x00000001
#define NVC597_TEXSAMP0_ADDRESS_U_CLAMP_TO_EDGE                    0x00000002
#define NVC597_TEXSAMP0_ADDRESS_U_BORDER                           0x00000003
#define NVC597_TEXSAMP0_ADDRESS_U_CLAMP_OGL                        0x00000004
#define NVC597_TEXSAMP0_ADDRESS_U_MIRROR_ONCE_CLAMP_TO_EDGE        0x00000005
#define NVC597_TEXSAMP0_ADDRESS_U_MIRROR_ONCE_BORDER               0x00000006
#define NVC597_TEXSAMP0_ADDRESS_U_MIRROR_ONCE_CLAMP_OGL            0x00000007
#define NVC597_TEXSAMP0_ADDRESS_V                                  5:3
#define NVC597_TEXSAMP0_ADDRESS_V_WRAP                             0x00000000
#define NVC597_TEXSAMP0_ADDRESS_V_MIRROR                           0x00000001
#define NVC597_TEXSAMP0_ADDRESS_V_CLAMP_TO_EDGE                    0x00000002
#define NVC597_TEXSAMP0_ADDRESS_V_BORDER                           0x00000003
#define NVC597_TEXSAMP0_ADDRESS_V_CLAMP_OGL                        0x00000004
#define NVC597_TEXSAMP0_ADDRESS_V_MIRROR_ONCE_CLAMP_TO_EDGE        0x00000005
#define NVC597_TEXSAMP0_ADDRESS_V_MIRROR_ONCE_BORDER               0x00000006
#define NVC597_TEXSAMP0_ADDRESS_V_MIRROR_ONCE_CLAMP_OGL            0x00000007
#define NVC597_TEXSAMP0_ADDRESS_P                                  8:6
#define NVC597_TEXSAMP0_ADDRESS_P_WRAP                             0x00000000
#define NVC597_TEXSAMP0_ADDRESS_P_MIRROR                           0x00000001
#define NVC597_TEXSAMP0_ADDRESS_P_CLAMP_TO_EDGE                    0x00000002
#define NVC597_TEXSAMP0_ADDRESS_P_BORDER                           0x00000003
#define NVC597_TEXSAMP0_ADDRESS_P_CLAMP_OGL                        0x00000004
#define NVC597_TEXSAMP0_ADDRESS_P_MIRROR_ONCE_CLAMP_TO_EDGE        0x00000005
#define NVC597_TEXSAMP0_ADDRESS_P_MIRROR_ONCE_BORDER               0x00000006
#define NVC597_TEXSAMP0_ADDRESS_P_MIRROR_ONCE_CLAMP_OGL            0x00000007
#define NVC597_TEXSAMP0_DEPTH_COMPARE                              9:9
#define NVC597_TEXSAMP0_DEPTH_COMPARE_FUNC                         12:10
#define NVC597_TEXSAMP0_DEPTH_COMPARE_FUNC_ZC_NEVER                0x00000000
#define NVC597_TEXSAMP0_DEPTH_COMPARE_FUNC_ZC_LESS                 0x00000001
#define NVC597_TEXSAMP0_DEPTH_COMPARE_FUNC_ZC_EQUAL                0x00000002
#define NVC597_TEXSAMP0_DEPTH_COMPARE_FUNC_ZC_LEQUAL               0x00000003
#define NVC597_TEXSAMP0_DEPTH_COMPARE_FUNC_ZC_GREATER              0x00000004
#define NVC597_TEXSAMP0_DEPTH_COMPARE_FUNC_ZC_NOTEQUAL             0x00000005
#define NVC597_TEXSAMP0_DEPTH_COMPARE_FUNC_ZC_GEQUAL               0x00000006
#define NVC597_TEXSAMP0_DEPTH_COMPARE_FUNC_ZC_ALWAYS               0x00000007
#define NVC597_TEXSAMP0_S_R_G_B_CONVERSION                         13:13
#define NVC597_TEXSAMP0_RESERVED0A                                 16:14
#define NVC597_TEXSAMP0_RESERVED0B                                 19:17
#define NVC597_TEXSAMP0_MAX_ANISOTROPY                             22:20
#define NVC597_TEXSAMP0_MAX_ANISOTROPY_ANISO_1_TO_1                0x00000000
#define NVC597_TEXSAMP0_MAX_ANISOTROPY_ANISO_2_TO_1                0x00000001
#define NVC597_TEXSAMP0_MAX_ANISOTROPY_ANISO_4_TO_1                0x00000002
#define NVC597_TEXSAMP0_MAX_ANISOTROPY_ANISO_6_TO_1                0x00000003
#define NVC597_TEXSAMP0_MAX_ANISOTROPY_ANISO_8_TO_1                0x00000004
#define NVC597_TEXSAMP0_MAX_ANISOTROPY_ANISO_10_TO_1               0x00000005
#define NVC597_TEXSAMP0_MAX_ANISOTROPY_ANISO_12_TO_1               0x00000006
#define NVC597_TEXSAMP0_MAX_ANISOTROPY_ANISO_16_TO_1               0x00000007
#define NVC597_TEXSAMP0_FORCED_INVALID                             31:31
#define NVC597_TEXSAMP1_MAG_FILTER                                 2:0
#define NVC597_TEXSAMP1_MAG_FILTER_MAG_POINT                       0x00000001
#define NVC597_TEXSAMP1_MAG_FILTER_MAG_LINEAR                      0x00000002
#define NVC597_TEXSAMP1_MAG_FILTER_VCAA_4_TAP                      0x00000003
#define NVC597_TEXSAMP1_MAG_FILTER_VCAA_8_TAP                      0x00000004
#define NVC597_TEXSAMP1_MIN_LOD_CLAMP_BEHAVIOR_FOR_NEAREST_MIP     3:3
#define NVC597_TEXSAMP1_MIN_LOD_CLAMP_BEHAVIOR_FOR_NEAREST_MIP_INTEGER_AND_FRACTION 0x00000000
#define NVC597_TEXSAMP1_MIN_LOD_CLAMP_BEHAVIOR_FOR_NEAREST_MIP_INTEGER_ONLY 0x00000001
#define NVC597_TEXSAMP1_MIN_FILTER                                 5:4
#define NVC597_TEXSAMP1_MIN_FILTER_MIN_POINT                       0x00000001
#define NVC597_TEXSAMP1_MIN_FILTER_MIN_LINEAR                      0x00000002
#define NVC597_TEXSAMP1_MIN_FILTER_MIN_ANISO                       0x00000003
#define NVC597_TEXSAMP1_MIP_FILTER                                 7:6
#define NVC597_TEXSAMP1_MIP_FILTER_MIP_NONE                        0x00000001
#define NVC597_TEXSAMP1_MIP_FILTER_MIP_POINT                       0x00000002
#define NVC597_TEXSAMP1_MIP_FILTER_MIP_LINEAR                      0x00000003
#define NVC597_TEXSAMP1_CUBEMAP_INTERFACE_FILTERING                9:8
#define NVC597_TEXSAMP1_CUBEMAP_INTERFACE_FILTERING_USE_WRAP       0x00000000
#define NVC597_TEXSAMP1_CUBEMAP_INTERFACE_FILTERING_OVERRIDE_WRAP  0x00000001
#define NVC597_TEXSAMP1_CUBEMAP_INTERFACE_FILTERING_AUTO_SPAN_SEAM 0x00000002
#define NVC597_TEXSAMP1_CUBEMAP_INTERFACE_FILTERING_AUTO_CROSS_SEAM 0x00000003
#define NVC597_TEXSAMP1_REDUCTION_FILTER                           11:10
#define NVC597_TEXSAMP1_REDUCTION_FILTER_RED_NONE                  0x00000000
#define NVC597_TEXSAMP1_REDUCTION_FILTER_RED_MINIMUM               0x00000001
#define NVC597_TEXSAMP1_REDUCTION_FILTER_RED_MAXIMUM               0x00000002
#define NVC597_TEXSAMP1_MIP_LOD_BIAS                               24:12
#define NVC597_TEXSAMP1_FLOAT_COORD_NORMALIZATION                  25:25
#define NVC597_TEXSAMP1_FLOAT_COORD_NORMALIZATION_USE_HEADER_SETTING 0x00000000
#define NVC597_TEXSAMP1_FLOAT_COORD_NORMALIZATION_FORCE_UNNORMALIZED_COORDS 0x00000001
#define NVC597_TEXSAMP1_TRILIN_OPT                                 30:26
#define NVC597_TEXSAMP2_MIN_LOD_CLAMP                              11:0
#define NVC597_TEXSAMP2_MAX_LOD_CLAMP                              23:12
#define NVC597_TEXSAMP2_S_R_G_B_BORDER_COLOR_R                     31:24
#define NVC597_TEXSAMP3_RESERVED12                                 11:0
#define NVC597_TEXSAMP3_S_R_G_B_BORDER_COLOR_G                     19:12
#define NVC597_TEXSAMP3_S_R_G_B_BORDER_COLOR_B                     27:20
#define NVC597_TEXSAMP4_BORDER_COLOR_R                             31:0
#define NVC597_TEXSAMP5_BORDER_COLOR_G                             31:0
#define NVC597_TEXSAMP6_BORDER_COLOR_B                             31:0
#define NVC597_TEXSAMP7_BORDER_COLOR_A                             31:0



#endif // #ifndef __CLC597TEX_H__
